# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/comments/v1/comments_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-strmprivacy/api/comments/v1/comments_v1.proto\x12\x1bstrmprivacy.api.comments.v1\x1a-strmprivacy/api/entities/v1/entities_v1.proto\x1a\x17validate/validate.proto\"`\n\x14\x43reateCommentRequest\x12H\n\x07\x63omment\x18\x01 \x01(\x0b\x32$.strmprivacy.api.entities.v1.CommentB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x07\x63omment\"W\n\x15\x43reateCommentResponse\x12>\n\x07\x63omment\x18\x01 \x01(\x0b\x32$.strmprivacy.api.entities.v1.CommentR\x07\x63omment\"\xa3\x01\n\x13ListCommentsRequest\x12P\n\nentity_ref\x18\x01 \x01(\x0b\x32\'.strmprivacy.api.entities.v1.GenericRefB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\tentityRef\x12\x1b\n\tpage_size\x18\x02 \x01(\x05R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\"\x80\x01\n\x14ListCommentsResponse\x12@\n\x08\x63omments\x18\x01 \x03(\x0b\x32$.strmprivacy.api.entities.v1.CommentR\x08\x63omments\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"B\n\x14\x44\x65leteCommentRequest\x12*\n\ncomment_id\x18\x01 \x01(\tB\x0b\xfa\x42\x08r\x06\xd0\x01\x00\xb0\x01\x01R\tcommentId\"\x17\n\x15\x44\x65leteCommentResponse2\xf6\x02\n\x0f\x43ommentsService\x12v\n\rCreateComment\x12\x31.strmprivacy.api.comments.v1.CreateCommentRequest\x1a\x32.strmprivacy.api.comments.v1.CreateCommentResponse\x12s\n\x0cListComments\x12\x30.strmprivacy.api.comments.v1.ListCommentsRequest\x1a\x31.strmprivacy.api.comments.v1.ListCommentsResponse\x12v\n\rDeleteComment\x12\x31.strmprivacy.api.comments.v1.DeleteCommentRequest\x1a\x32.strmprivacy.api.comments.v1.DeleteCommentResponseBi\n\x1eio.strmprivacy.api.comments.v1P\x01ZEgithub.com/strmprivacy/api-definitions-go/v3/api/comments/v1;commentsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.comments.v1.comments_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036io.strmprivacy.api.comments.v1P\001ZEgithub.com/strmprivacy/api-definitions-go/v3/api/comments/v1;comments'
  _CREATECOMMENTREQUEST.fields_by_name['comment']._options = None
  _CREATECOMMENTREQUEST.fields_by_name['comment']._serialized_options = b'\372B\005\212\001\002\020\001'
  _LISTCOMMENTSREQUEST.fields_by_name['entity_ref']._options = None
  _LISTCOMMENTSREQUEST.fields_by_name['entity_ref']._serialized_options = b'\372B\005\212\001\002\020\001'
  _DELETECOMMENTREQUEST.fields_by_name['comment_id']._options = None
  _DELETECOMMENTREQUEST.fields_by_name['comment_id']._serialized_options = b'\372B\010r\006\320\001\000\260\001\001'
  _CREATECOMMENTREQUEST._serialized_start=150
  _CREATECOMMENTREQUEST._serialized_end=246
  _CREATECOMMENTRESPONSE._serialized_start=248
  _CREATECOMMENTRESPONSE._serialized_end=335
  _LISTCOMMENTSREQUEST._serialized_start=338
  _LISTCOMMENTSREQUEST._serialized_end=501
  _LISTCOMMENTSRESPONSE._serialized_start=504
  _LISTCOMMENTSRESPONSE._serialized_end=632
  _DELETECOMMENTREQUEST._serialized_start=634
  _DELETECOMMENTREQUEST._serialized_end=700
  _DELETECOMMENTRESPONSE._serialized_start=702
  _DELETECOMMENTRESPONSE._serialized_end=725
  _COMMENTSSERVICE._serialized_start=728
  _COMMENTSSERVICE._serialized_end=1102
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from strmprivacy.api.audit.v1 import audit_v1_pb2 as strmprivacy_dot_api_dot_audit_dot_v1_dot_audit__v1__pb2


class AuditServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetAuditTrail = channel.unary_unary(
                '/strmprivacy.api.audit.v1.AuditService/GetAuditTrail',
                request_serializer=strmprivacy_dot_api_dot_audit_dot_v1_dot_audit__v1__pb2.GetAuditTrailRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_audit_dot_v1_dot_audit__v1__pb2.GetAuditTrailResponse.FromString,
                )
        self.CreateAuditTrailEntry = channel.unary_unary(
                '/strmprivacy.api.audit.v1.AuditService/CreateAuditTrailEntry',
                request_serializer=strmprivacy_dot_api_dot_audit_dot_v1_dot_audit__v1__pb2.CreateAuditTrailEntryRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_audit_dot_v1_dot_audit__v1__pb2.CreateAuditTrailEntryResponse.FromString,
                )


class AuditServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetAuditTrail(self, request, context):
        """GetAuditTrail returns a list of audit trail entries for a given entity to be shown to an
        end user, e.g. in the Console.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateAuditTrailEntry(self, request, context):
        """CreateAuditTrailEntry creates a new audit trail entry for a given entity,
        and is called by source system owning the entity whenever a relevant change is made.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AuditServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetAuditTrail': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAuditTrail,
                    request_deserializer=strmprivacy_dot_api_dot_audit_dot_v1_dot_audit__v1__pb2.GetAuditTrailRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_audit_dot_v1_dot_audit__v1__pb2.GetAuditTrailResponse.SerializeToString,
            ),
            'CreateAuditTrailEntry': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateAuditTrailEntry,
                    request_deserializer=strmprivacy_dot_api_dot_audit_dot_v1_dot_audit__v1__pb2.CreateAuditTrailEntryRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_audit_dot_v1_dot_audit__v1__pb2.CreateAuditTrailEntryResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'strmprivacy.api.audit.v1.AuditService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class AuditService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetAuditTrail(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.audit.v1.AuditService/GetAuditTrail',
            strmprivacy_dot_api_dot_audit_dot_v1_dot_audit__v1__pb2.GetAuditTrailRequest.SerializeToString,
            strmprivacy_dot_api_dot_audit_dot_v1_dot_audit__v1__pb2.GetAuditTrailResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateAuditTrailEntry(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.audit.v1.AuditService/CreateAuditTrailEntry',
            strmprivacy_dot_api_dot_audit_dot_v1_dot_audit__v1__pb2.CreateAuditTrailEntryRequest.SerializeToString,
            strmprivacy_dot_api_dot_audit_dot_v1_dot_audit__v1__pb2.CreateAuditTrailEntryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/categories/v1alpha/categories_v1alpha.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from strmprivacy.api.paging.v1alpha import paging_v1alpha_pb2 as strmprivacy_dot_api_dot_paging_dot_v1alpha_dot_paging__v1alpha__pb2
from validate import validate_pb2 as validate_dot_validate__pb2
from strmprivacy.api.entities.v1alpha import entities_v1alpha_pb2 as strmprivacy_dot_api_dot_entities_dot_v1alpha_dot_entities__v1alpha__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;strmprivacy/api/categories/v1alpha/categories_v1alpha.proto\x12\"strmprivacy.api.categories.v1alpha\x1a\x33strmprivacy/api/paging/v1alpha/paging_v1alpha.proto\x1a\x17validate/validate.proto\x1a\x37strmprivacy/api/entities/v1alpha/entities_v1alpha.proto\"\xa3\x01\n\x15ListCategoriesRequest\x12\x43\n\x04type\x18\x01 \x01(\x0e\x32/.strmprivacy.api.entities.v1alpha.Category.TypeR\x04type\x12\x45\n\tpage_info\x18\x02 \x01(\x0b\x32(.strmprivacy.api.paging.v1alpha.PageInfoR\x08pageInfo\"\xab\x01\n\x16ListCategoriesResponse\x12J\n\ncategories\x18\x01 \x03(\x0b\x32*.strmprivacy.api.entities.v1alpha.CategoryR\ncategories\x12\x45\n\tpage_info\x18\x02 \x01(\x0b\x32(.strmprivacy.api.paging.v1alpha.PageInfoR\x08pageInfo\".\n\x12GetCategoryRequest\x12\x18\n\x02id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01R\x02id\"]\n\x13GetCategoryResponse\x12\x46\n\x08\x63\x61tegory\x18\x01 \x01(\x0b\x32*.strmprivacy.api.entities.v1alpha.CategoryR\x08\x63\x61tegory\"_\n\x15UpsertCategoryRequest\x12\x46\n\x08\x63\x61tegory\x18\x01 \x01(\x0b\x32*.strmprivacy.api.entities.v1alpha.CategoryR\x08\x63\x61tegory\"`\n\x16UpsertCategoryResponse\x12\x46\n\x08\x63\x61tegory\x18\x01 \x01(\x0b\x32*.strmprivacy.api.entities.v1alpha.CategoryR\x08\x63\x61tegory2\xa7\x03\n\x11\x43\x61tegoriesService\x12\x87\x01\n\x0eListCategories\x12\x39.strmprivacy.api.categories.v1alpha.ListCategoriesRequest\x1a:.strmprivacy.api.categories.v1alpha.ListCategoriesResponse\x12~\n\x0bGetCategory\x12\x36.strmprivacy.api.categories.v1alpha.GetCategoryRequest\x1a\x37.strmprivacy.api.categories.v1alpha.GetCategoryResponse\x12\x87\x01\n\x0eUpsertCategory\x12\x39.strmprivacy.api.categories.v1alpha.UpsertCategoryRequest\x1a:.strmprivacy.api.categories.v1alpha.UpsertCategoryResponseBy\n%io.strmprivacy.api.categories.v1alphaP\x01ZNgithub.com/strmprivacy/api-definitions-go/v3/api/categories/v1alpha;categoriesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.categories.v1alpha.categories_v1alpha_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%io.strmprivacy.api.categories.v1alphaP\001ZNgithub.com/strmprivacy/api-definitions-go/v3/api/categories/v1alpha;categories'
  _GETCATEGORYREQUEST.fields_by_name['id']._options = None
  _GETCATEGORYREQUEST.fields_by_name['id']._serialized_options = b'\372B\005r\003\260\001\001'
  _LISTCATEGORIESREQUEST._serialized_start=235
  _LISTCATEGORIESREQUEST._serialized_end=398
  _LISTCATEGORIESRESPONSE._serialized_start=401
  _LISTCATEGORIESRESPONSE._serialized_end=572
  _GETCATEGORYREQUEST._serialized_start=574
  _GETCATEGORYREQUEST._serialized_end=620
  _GETCATEGORYRESPONSE._serialized_start=622
  _GETCATEGORYRESPONSE._serialized_end=715
  _UPSERTCATEGORYREQUEST._serialized_start=717
  _UPSERTCATEGORYREQUEST._serialized_end=812
  _UPSERTCATEGORYRESPONSE._serialized_start=814
  _UPSERTCATEGORYRESPONSE._serialized_end=910
  _CATEGORIESSERVICE._serialized_start=913
  _CATEGORIESSERVICE._serialized_end=1336
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from strmprivacy.api.ropa.v1alpha import ropa_v1alpha_pb2 as strmprivacy_dot_api_dot_ropa_dot_v1alpha_dot_ropa__v1alpha__pb2


class RopaServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetRopa = channel.unary_unary(
                '/strmprivacy.api.ropa.v1alpha.RopaService/GetRopa',
                request_serializer=strmprivacy_dot_api_dot_ropa_dot_v1alpha_dot_ropa__v1alpha__pb2.GetRopaRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_ropa_dot_v1alpha_dot_ropa__v1alpha__pb2.GetRopaResponse.FromString,
                )
        self.CreateRecord = channel.unary_unary(
                '/strmprivacy.api.ropa.v1alpha.RopaService/CreateRecord',
                request_serializer=strmprivacy_dot_api_dot_ropa_dot_v1alpha_dot_ropa__v1alpha__pb2.CreateRecordRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_ropa_dot_v1alpha_dot_ropa__v1alpha__pb2.CreateRecordResponse.FromString,
                )
        self.GetRecord = channel.unary_unary(
                '/strmprivacy.api.ropa.v1alpha.RopaService/GetRecord',
                request_serializer=strmprivacy_dot_api_dot_ropa_dot_v1alpha_dot_ropa__v1alpha__pb2.GetRecordRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_ropa_dot_v1alpha_dot_ropa__v1alpha__pb2.GetRecordResponse.FromString,
                )


class RopaServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetRopa(self, request, context):
        """This will return all (latest versions of) the records.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateRecord(self, request, context):
        """Create a new record (leave its id empty) or a new version of an existing record (provide its id and current version).
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRecord(self, request, context):
        """Get a record by its id.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_RopaServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetRopa': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRopa,
                    request_deserializer=strmprivacy_dot_api_dot_ropa_dot_v1alpha_dot_ropa__v1alpha__pb2.GetRopaRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_ropa_dot_v1alpha_dot_ropa__v1alpha__pb2.GetRopaResponse.SerializeToString,
            ),
            'CreateRecord': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateRecord,
                    request_deserializer=strmprivacy_dot_api_dot_ropa_dot_v1alpha_dot_ropa__v1alpha__pb2.CreateRecordRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_ropa_dot_v1alpha_dot_ropa__v1alpha__pb2.CreateRecordResponse.SerializeToString,
            ),
            'GetRecord': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRecord,
                    request_deserializer=strmprivacy_dot_api_dot_ropa_dot_v1alpha_dot_ropa__v1alpha__pb2.GetRecordRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_ropa_dot_v1alpha_dot_ropa__v1alpha__pb2.GetRecordResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'strmprivacy.api.ropa.v1alpha.RopaService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class RopaService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetRopa(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.ropa.v1alpha.RopaService/GetRopa',
            strmprivacy_dot_api_dot_ropa_dot_v1alpha_dot_ropa__v1alpha__pb2.GetRopaRequest.SerializeToString,
            strmprivacy_dot_api_dot_ropa_dot_v1alpha_dot_ropa__v1alpha__pb2.GetRopaResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateRecord(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.ropa.v1alpha.RopaService/CreateRecord',
            strmprivacy_dot_api_dot_ropa_dot_v1alpha_dot_ropa__v1alpha__pb2.CreateRecordRequest.SerializeToString,
            strmprivacy_dot_api_dot_ropa_dot_v1alpha_dot_ropa__v1alpha__pb2.CreateRecordResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetRecord(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.ropa.v1alpha.RopaService/GetRecord',
            strmprivacy_dot_api_dot_ropa_dot_v1alpha_dot_ropa__v1alpha__pb2.GetRecordRequest.SerializeToString,
            strmprivacy_dot_api_dot_ropa_dot_v1alpha_dot_ropa__v1alpha__pb2.GetRecordResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from strmprivacy.api.parties.v1alpha import parties_v1alpha_pb2 as strmprivacy_dot_api_dot_parties_dot_v1alpha_dot_parties__v1alpha__pb2


class PartiesServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListParties = channel.unary_unary(
                '/strmprivacy.api.parties.v1alpha.PartiesService/ListParties',
                request_serializer=strmprivacy_dot_api_dot_parties_dot_v1alpha_dot_parties__v1alpha__pb2.ListPartiesRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_parties_dot_v1alpha_dot_parties__v1alpha__pb2.ListPartiesResponse.FromString,
                )
        self.GetParty = channel.unary_unary(
                '/strmprivacy.api.parties.v1alpha.PartiesService/GetParty',
                request_serializer=strmprivacy_dot_api_dot_parties_dot_v1alpha_dot_parties__v1alpha__pb2.GetPartyRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_parties_dot_v1alpha_dot_parties__v1alpha__pb2.GetPartyResponse.FromString,
                )
        self.UpsertParty = channel.unary_unary(
                '/strmprivacy.api.parties.v1alpha.PartiesService/UpsertParty',
                request_serializer=strmprivacy_dot_api_dot_parties_dot_v1alpha_dot_parties__v1alpha__pb2.UpsertPartyRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_parties_dot_v1alpha_dot_parties__v1alpha__pb2.UpsertPartyResponse.FromString,
                )


class PartiesServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListParties(self, request, context):
        """List all parties for an organization. The organization is derived from the calling user.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetParty(self, request, context):
        """Get a party by its id
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpsertParty(self, request, context):
        """Create or update a party. To create a party, leave its id empty. To update a party, set its id.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_PartiesServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListParties': grpc.unary_unary_rpc_method_handler(
                    servicer.ListParties,
                    request_deserializer=strmprivacy_dot_api_dot_parties_dot_v1alpha_dot_parties__v1alpha__pb2.ListPartiesRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_parties_dot_v1alpha_dot_parties__v1alpha__pb2.ListPartiesResponse.SerializeToString,
            ),
            'GetParty': grpc.unary_unary_rpc_method_handler(
                    servicer.GetParty,
                    request_deserializer=strmprivacy_dot_api_dot_parties_dot_v1alpha_dot_parties__v1alpha__pb2.GetPartyRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_parties_dot_v1alpha_dot_parties__v1alpha__pb2.GetPartyResponse.SerializeToString,
            ),
            'UpsertParty': grpc.unary_unary_rpc_method_handler(
                    servicer.UpsertParty,
                    request_deserializer=strmprivacy_dot_api_dot_parties_dot_v1alpha_dot_parties__v1alpha__pb2.UpsertPartyRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_parties_dot_v1alpha_dot_parties__v1alpha__pb2.UpsertPartyResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'strmprivacy.api.parties.v1alpha.PartiesService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class PartiesService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListParties(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.parties.v1alpha.PartiesService/ListParties',
            strmprivacy_dot_api_dot_parties_dot_v1alpha_dot_parties__v1alpha__pb2.ListPartiesRequest.SerializeToString,
            strmprivacy_dot_api_dot_parties_dot_v1alpha_dot_parties__v1alpha__pb2.ListPartiesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetParty(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.parties.v1alpha.PartiesService/GetParty',
            strmprivacy_dot_api_dot_parties_dot_v1alpha_dot_parties__v1alpha__pb2.GetPartyRequest.SerializeToString,
            strmprivacy_dot_api_dot_parties_dot_v1alpha_dot_parties__v1alpha__pb2.GetPartyResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpsertParty(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.parties.v1alpha.PartiesService/UpsertParty',
            strmprivacy_dot_api_dot_parties_dot_v1alpha_dot_parties__v1alpha__pb2.UpsertPartyRequest.SerializeToString,
            strmprivacy_dot_api_dot_parties_dot_v1alpha_dot_parties__v1alpha__pb2.UpsertPartyResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from strmprivacy.api.comments.v1 import comments_v1_pb2 as strmprivacy_dot_api_dot_comments_dot_v1_dot_comments__v1__pb2


class CommentsServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateComment = channel.unary_unary(
                '/strmprivacy.api.comments.v1.CommentsService/CreateComment',
                request_serializer=strmprivacy_dot_api_dot_comments_dot_v1_dot_comments__v1__pb2.CreateCommentRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_comments_dot_v1_dot_comments__v1__pb2.CreateCommentResponse.FromString,
                )
        self.ListComments = channel.unary_unary(
                '/strmprivacy.api.comments.v1.CommentsService/ListComments',
                request_serializer=strmprivacy_dot_api_dot_comments_dot_v1_dot_comments__v1__pb2.ListCommentsRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_comments_dot_v1_dot_comments__v1__pb2.ListCommentsResponse.FromString,
                )
        self.DeleteComment = channel.unary_unary(
                '/strmprivacy.api.comments.v1.CommentsService/DeleteComment',
                request_serializer=strmprivacy_dot_api_dot_comments_dot_v1_dot_comments__v1__pb2.DeleteCommentRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_comments_dot_v1_dot_comments__v1__pb2.DeleteCommentResponse.FromString,
                )


class CommentsServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateComment(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListComments(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteComment(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_CommentsServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateComment': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateComment,
                    request_deserializer=strmprivacy_dot_api_dot_comments_dot_v1_dot_comments__v1__pb2.CreateCommentRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_comments_dot_v1_dot_comments__v1__pb2.CreateCommentResponse.SerializeToString,
            ),
            'ListComments': grpc.unary_unary_rpc_method_handler(
                    servicer.ListComments,
                    request_deserializer=strmprivacy_dot_api_dot_comments_dot_v1_dot_comments__v1__pb2.ListCommentsRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_comments_dot_v1_dot_comments__v1__pb2.ListCommentsResponse.SerializeToString,
            ),
            'DeleteComment': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteComment,
                    request_deserializer=strmprivacy_dot_api_dot_comments_dot_v1_dot_comments__v1__pb2.DeleteCommentRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_comments_dot_v1_dot_comments__v1__pb2.DeleteCommentResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'strmprivacy.api.comments.v1.CommentsService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class CommentsService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateComment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.comments.v1.CommentsService/CreateComment',
            strmprivacy_dot_api_dot_comments_dot_v1_dot_comments__v1__pb2.CreateCommentRequest.SerializeToString,
            strmprivacy_dot_api_dot_comments_dot_v1_dot_comments__v1__pb2.CreateCommentResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListComments(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.comments.v1.CommentsService/ListComments',
            strmprivacy_dot_api_dot_comments_dot_v1_dot_comments__v1__pb2.ListCommentsRequest.SerializeToString,
            strmprivacy_dot_api_dot_comments_dot_v1_dot_comments__v1__pb2.ListCommentsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteComment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.comments.v1.CommentsService/DeleteComment',
            strmprivacy_dot_api_dot_comments_dot_v1_dot_comments__v1__pb2.DeleteCommentRequest.SerializeToString,
            strmprivacy_dot_api_dot_comments_dot_v1_dot_comments__v1__pb2.DeleteCommentResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/notifications/v1/notifications_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2
from validate import validate_pb2 as validate_dot_validate__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7strmprivacy/api/notifications/v1/notifications_v1.proto\x12 strmprivacy.api.notifications.v1\x1a-strmprivacy/api/entities/v1/entities_v1.proto\x1a\x17validate/validate.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x1d\n\x1bReceiveNotificationsRequest\"v\n\x1cReceiveNotificationsResponse\x12V\n\x0cnotification\x18\x01 \x01(\x0b\x32\x32.strmprivacy.api.notifications.v1.UserNotificationR\x0cnotification\"\xca\x01\n\x18NotifySubscribersRequest\x12P\n\nentity_ref\x18\x01 \x01(\x0b\x32\'.strmprivacy.api.entities.v1.GenericRefB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\tentityRef\x12\\\n\x0cnotification\x18\x02 \x01(\x0b\x32..strmprivacy.api.notifications.v1.NotificationB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x0cnotification\"\x1b\n\x19NotifySubscribersResponse\"\xad\x01\n\x12NotifyUsersRequest\x12\x39\n\x11\x65xternal_user_ids\x18\x01 \x03(\tB\r\xfa\x42\n\x92\x01\x07\"\x05r\x03\xb0\x01\x01R\x0f\x65xternalUserIds\x12\\\n\x0cnotification\x18\x02 \x01(\x0b\x32..strmprivacy.api.notifications.v1.NotificationB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x0cnotification\"\x15\n\x13NotifyUsersResponse\"\x83\x02\n\x0cNotification\x12\x45\n\x0b\x63reate_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xfa\x42\x05\xb2\x01\x02\x08\x00R\ncreateTime\x12@\n\x07\x63omment\x18\x02 \x01(\x0b\x32$.strmprivacy.api.entities.v1.CommentH\x00R\x07\x63omment\x12Z\n\x11\x61udit_trail_entry\x18\x03 \x01(\x0b\x32,.strmprivacy.api.entities.v1.AuditTrailEntryH\x00R\x0f\x61uditTrailEntryB\x0e\n\x0cnotification\"\xc8\x02\n\x10UserNotification\x12\x1b\n\x02id\x18\x01 \x01(\tB\x0b\xfa\x42\x08r\x06\xd0\x01\x01\xb0\x01\x01R\x02id\x12\\\n\x0cnotification\x18\x02 \x01(\x0b\x32..strmprivacy.api.notifications.v1.NotificationB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x0cnotification\x12\x1f\n\x06reason\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x06reason\x12(\n\x10\x65xternal_user_id\x18\x04 \x01(\tR\x0e\x65xternalUserId\x12J\n\x0email_sent_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xfa\x42\x05\xb2\x01\x02\x08\x00R\x0cmailSentTime\x12\"\n\rhas_been_seen\x18\x06 \x01(\x08R\x0bhasBeenSeen\"\xa8\x01\n\x1dSubscribeNotificationsRequest\x12\x35\n\x10\x65xternal_user_id\x18\x01 \x01(\tB\x0b\xfa\x42\x08r\x06\xd0\x01\x01\xb0\x01\x01R\x0e\x65xternalUserId\x12P\n\nentity_ref\x18\x02 \x01(\x0b\x32\'.strmprivacy.api.entities.v1.GenericRefB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\tentityRef\" \n\x1eSubscribeNotificationsResponse\"\xaa\x01\n\x1fUnSubscribeNotificationsRequest\x12\x35\n\x10\x65xternal_user_id\x18\x01 \x01(\tB\x0b\xfa\x42\x08r\x06\xd0\x01\x01\xb0\x01\x01R\x0e\x65xternalUserId\x12P\n\nentity_ref\x18\x02 \x01(\x0b\x32\'.strmprivacy.api.entities.v1.GenericRefB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\tentityRef\"\"\n UnSubscribeNotificationsResponse\"Q\n\x18ListSubscriptionsRequest\x12\x35\n\x10\x65xternal_user_id\x18\x01 \x01(\tB\x0b\xfa\x42\x08r\x06\xd0\x01\x01\xb0\x01\x01R\x0e\x65xternalUserId\"q\n\x19ListSubscriptionsResponse\x12T\n\rsubscriptions\x18\x01 \x03(\x0b\x32..strmprivacy.api.notifications.v1.SubscriptionR\rsubscriptions\"\x97\x01\n\x0cSubscription\x12\x35\n\x10\x65xternal_user_id\x18\x01 \x01(\tB\x0b\xfa\x42\x08r\x06\xd0\x01\x01\xb0\x01\x01R\x0e\x65xternalUserId\x12P\n\nentity_ref\x18\x02 \x01(\x0b\x32\'.strmprivacy.api.entities.v1.GenericRefB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\tentityRef\"\xd8\x02\n\x18ListNotificationsRequest\x12\x35\n\x10\x65xternal_user_id\x18\x01 \x01(\tB\x0b\xfa\x42\x08r\x06\xd0\x01\x01\xb0\x01\x01R\x0e\x65xternalUserId\x12P\n\nentity_ref\x18\x02 \x01(\x0b\x32\'.strmprivacy.api.entities.v1.GenericRefB\x08\xfa\x42\x05\x8a\x01\x02\x10\x00R\tentityRef\x12\x1b\n\tpage_size\x18\x03 \x01(\x05R\x08pageSize\x12\x1d\n\npage_token\x18\x04 \x01(\tR\tpageToken\x12\x45\n\x0boffset_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xfa\x42\x05\xb2\x01\x02\x08\x00R\noffsetTime\x12\x30\n\x14include_already_seen\x18\x06 \x01(\x08R\x12includeAlreadySeen\"\x9d\x01\n\x19ListNotificationsResponse\x12X\n\rnotifications\x18\x01 \x03(\x0b\x32\x32.strmprivacy.api.notifications.v1.UserNotificationR\rnotifications\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"\\\n$AlterNotificationsHasBeenSeenRequest\x12\x10\n\x03ids\x18\x01 \x03(\tR\x03ids\x12\"\n\rhas_been_seen\x18\x02 \x01(\x08R\x0bhasBeenSeen\"\'\n%AlterNotificationsHasBeenSeenResponse2\xce\t\n\x14NotificationsService\x12\x9b\x01\n\x16SubscribeNotifications\x12?.strmprivacy.api.notifications.v1.SubscribeNotificationsRequest\x1a@.strmprivacy.api.notifications.v1.SubscribeNotificationsResponse\x12\xa1\x01\n\x18UnSubscribeNotifications\x12\x41.strmprivacy.api.notifications.v1.UnSubscribeNotificationsRequest\x1a\x42.strmprivacy.api.notifications.v1.UnSubscribeNotificationsResponse\x12\x8c\x01\n\x11ListSubscriptions\x12:.strmprivacy.api.notifications.v1.ListSubscriptionsRequest\x1a;.strmprivacy.api.notifications.v1.ListSubscriptionsResponse\x12\x8c\x01\n\x11NotifySubscribers\x12:.strmprivacy.api.notifications.v1.NotifySubscribersRequest\x1a;.strmprivacy.api.notifications.v1.NotifySubscribersResponse\x12z\n\x0bNotifyUsers\x12\x34.strmprivacy.api.notifications.v1.NotifyUsersRequest\x1a\x35.strmprivacy.api.notifications.v1.NotifyUsersResponse\x12\x97\x01\n\x14ReceiveNotifications\x12=.strmprivacy.api.notifications.v1.ReceiveNotificationsRequest\x1a>.strmprivacy.api.notifications.v1.ReceiveNotificationsResponse0\x01\x12\x8c\x01\n\x11ListNotifications\x12:.strmprivacy.api.notifications.v1.ListNotificationsRequest\x1a;.strmprivacy.api.notifications.v1.ListNotificationsResponse\x12\xb0\x01\n\x1d\x41lterNotificationsHasBeenSeen\x12\x46.strmprivacy.api.notifications.v1.AlterNotificationsHasBeenSeenRequest\x1aG.strmprivacy.api.notifications.v1.AlterNotificationsHasBeenSeenResponseBx\n#io.strmprivacy.api.notifications.v1P\x01ZOgithub.com/strmprivacy/api-definitions-go/v3/api/notifications/v1;notificationsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.notifications.v1.notifications_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#io.strmprivacy.api.notifications.v1P\001ZOgithub.com/strmprivacy/api-definitions-go/v3/api/notifications/v1;notifications'
  _NOTIFYSUBSCRIBERSREQUEST.fields_by_name['entity_ref']._options = None
  _NOTIFYSUBSCRIBERSREQUEST.fields_by_name['entity_ref']._serialized_options = b'\372B\005\212\001\002\020\001'
  _NOTIFYSUBSCRIBERSREQUEST.fields_by_name['notification']._options = None
  _NOTIFYSUBSCRIBERSREQUEST.fields_by_name['notification']._serialized_options = b'\372B\005\212\001\002\020\001'
  _NOTIFYUSERSREQUEST.fields_by_name['external_user_ids']._options = None
  _NOTIFYUSERSREQUEST.fields_by_name['external_user_ids']._serialized_options = b'\372B\n\222\001\007\"\005r\003\260\001\001'
  _NOTIFYUSERSREQUEST.fields_by_name['notification']._options = None
  _NOTIFYUSERSREQUEST.fields_by_name['notification']._serialized_options = b'\372B\005\212\001\002\020\001'
  _NOTIFICATION.fields_by_name['create_time']._options = None
  _NOTIFICATION.fields_by_name['create_time']._serialized_options = b'\372B\005\262\001\002\010\000'
  _USERNOTIFICATION.fields_by_name['id']._options = None
  _USERNOTIFICATION.fields_by_name['id']._serialized_options = b'\372B\010r\006\320\001\001\260\001\001'
  _USERNOTIFICATION.fields_by_name['notification']._options = None
  _USERNOTIFICATION.fields_by_name['notification']._serialized_options = b'\372B\005\212\001\002\020\001'
  _USERNOTIFICATION.fields_by_name['reason']._options = None
  _USERNOTIFICATION.fields_by_name['reason']._serialized_options = b'\372B\004r\002\020\001'
  _USERNOTIFICATION.fields_by_name['mail_sent_time']._options = None
  _USERNOTIFICATION.fields_by_name['mail_sent_time']._serialized_options = b'\372B\005\262\001\002\010\000'
  _SUBSCRIBENOTIFICATIONSREQUEST.fields_by_name['external_user_id']._options = None
  _SUBSCRIBENOTIFICATIONSREQUEST.fields_by_name['external_user_id']._serialized_options = b'\372B\010r\006\320\001\001\260\001\001'
  _SUBSCRIBENOTIFICATIONSREQUEST.fields_by_name['entity_ref']._options = None
  _SUBSCRIBENOTIFICATIONSREQUEST.fields_by_name['entity_ref']._serialized_options = b'\372B\005\212\001\002\020\001'
  _UNSUBSCRIBENOTIFICATIONSREQUEST.fields_by_name['external_user_id']._options = None
  _UNSUBSCRIBENOTIFICATIONSREQUEST.fields_by_name['external_user_id']._serialized_options = b'\372B\010r\006\320\001\001\260\001\001'
  _UNSUBSCRIBENOTIFICATIONSREQUEST.fields_by_name['entity_ref']._options = None
  _UNSUBSCRIBENOTIFICATIONSREQUEST.fields_by_name['entity_ref']._serialized_options = b'\372B\005\212\001\002\020\001'
  _LISTSUBSCRIPTIONSREQUEST.fields_by_name['external_user_id']._options = None
  _LISTSUBSCRIPTIONSREQUEST.fields_by_name['external_user_id']._serialized_options = b'\372B\010r\006\320\001\001\260\001\001'
  _SUBSCRIPTION.fields_by_name['external_user_id']._options = None
  _SUBSCRIPTION.fields_by_name['external_user_id']._serialized_options = b'\372B\010r\006\320\001\001\260\001\001'
  _SUBSCRIPTION.fields_by_name['entity_ref']._options = None
  _SUBSCRIPTION.fields_by_name['entity_ref']._serialized_options = b'\372B\005\212\001\002\020\001'
  _LISTNOTIFICATIONSREQUEST.fields_by_name['external_user_id']._options = None
  _LISTNOTIFICATIONSREQUEST.fields_by_name['external_user_id']._serialized_options = b'\372B\010r\006\320\001\001\260\001\001'
  _LISTNOTIFICATIONSREQUEST.fields_by_name['entity_ref']._options = None
  _LISTNOTIFICATIONSREQUEST.fields_by_name['entity_ref']._serialized_options = b'\372B\005\212\001\002\020\000'
  _LISTNOTIFICATIONSREQUEST.fields_by_name['offset_time']._options = None
  _LISTNOTIFICATIONSREQUEST.fields_by_name['offset_time']._serialized_options = b'\372B\005\262\001\002\010\000'
  _RECEIVENOTIFICATIONSREQUEST._serialized_start=198
  _RECEIVENOTIFICATIONSREQUEST._serialized_end=227
  _RECEIVENOTIFICATIONSRESPONSE._serialized_start=229
  _RECEIVENOTIFICATIONSRESPONSE._serialized_end=347
  _NOTIFYSUBSCRIBERSREQUEST._serialized_start=350
  _NOTIFYSUBSCRIBERSREQUEST._serialized_end=552
  _NOTIFYSUBSCRIBERSRESPONSE._serialized_start=554
  _NOTIFYSUBSCRIBERSRESPONSE._serialized_end=581
  _NOTIFYUSERSREQUEST._serialized_start=584
  _NOTIFYUSERSREQUEST._serialized_end=757
  _NOTIFYUSERSRESPONSE._serialized_start=759
  _NOTIFYUSERSRESPONSE._serialized_end=780
  _NOTIFICATION._serialized_start=783
  _NOTIFICATION._serialized_end=1042
  _USERNOTIFICATION._serialized_start=1045
  _USERNOTIFICATION._serialized_end=1373
  _SUBSCRIBENOTIFICATIONSREQUEST._serialized_start=1376
  _SUBSCRIBENOTIFICATIONSREQUEST._serialized_end=1544
  _SUBSCRIBENOTIFICATIONSRESPONSE._serialized_start=1546
  _SUBSCRIBENOTIFICATIONSRESPONSE._serialized_end=1578
  _UNSUBSCRIBENOTIFICATIONSREQUEST._serialized_start=1581
  _UNSUBSCRIBENOTIFICATIONSREQUEST._serialized_end=1751
  _UNSUBSCRIBENOTIFICATIONSRESPONSE._serialized_start=1753
  _UNSUBSCRIBENOTIFICATIONSRESPONSE._serialized_end=1787
  _LISTSUBSCRIPTIONSREQUEST._serialized_start=1789
  _LISTSUBSCRIPTIONSREQUEST._serialized_end=1870
  _LISTSUBSCRIPTIONSRESPONSE._serialized_start=1872
  _LISTSUBSCRIPTIONSRESPONSE._serialized_end=1985
  _SUBSCRIPTION._serialized_start=1988
  _SUBSCRIPTION._serialized_end=2139
  _LISTNOTIFICATIONSREQUEST._serialized_start=2142
  _LISTNOTIFICATIONSREQUEST._serialized_end=2486
  _LISTNOTIFICATIONSRESPONSE._serialized_start=2489
  _LISTNOTIFICATIONSRESPONSE._serialized_end=2646
  _ALTERNOTIFICATIONSHASBEENSEENREQUEST._serialized_start=2648
  _ALTERNOTIFICATIONSHASBEENSEENREQUEST._serialized_end=2740
  _ALTERNOTIFICATIONSHASBEENSEENRESPONSE._serialized_start=2742
  _ALTERNOTIFICATIONSHASBEENSEENRESPONSE._serialized_end=2781
  _NOTIFICATIONSSERVICE._serialized_start=2784
  _NOTIFICATIONSSERVICE._serialized_end=4014
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from strmprivacy.api.categories.v1alpha import categories_v1alpha_pb2 as strmprivacy_dot_api_dot_categories_dot_v1alpha_dot_categories__v1alpha__pb2


class CategoriesServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListCategories = channel.unary_unary(
                '/strmprivacy.api.categories.v1alpha.CategoriesService/ListCategories',
                request_serializer=strmprivacy_dot_api_dot_categories_dot_v1alpha_dot_categories__v1alpha__pb2.ListCategoriesRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_categories_dot_v1alpha_dot_categories__v1alpha__pb2.ListCategoriesResponse.FromString,
                )
        self.GetCategory = channel.unary_unary(
                '/strmprivacy.api.categories.v1alpha.CategoriesService/GetCategory',
                request_serializer=strmprivacy_dot_api_dot_categories_dot_v1alpha_dot_categories__v1alpha__pb2.GetCategoryRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_categories_dot_v1alpha_dot_categories__v1alpha__pb2.GetCategoryResponse.FromString,
                )
        self.UpsertCategory = channel.unary_unary(
                '/strmprivacy.api.categories.v1alpha.CategoriesService/UpsertCategory',
                request_serializer=strmprivacy_dot_api_dot_categories_dot_v1alpha_dot_categories__v1alpha__pb2.UpsertCategoryRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_categories_dot_v1alpha_dot_categories__v1alpha__pb2.UpsertCategoryResponse.FromString,
                )


class CategoriesServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListCategories(self, request, context):
        """List all categories, optionally filtered for a given type. The organization is derived from the calling user.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCategory(self, request, context):
        """Get a category by id.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpsertCategory(self, request, context):
        """Create or update a category. To create a category, leave its id empty. To update a category, set its id.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_CategoriesServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListCategories': grpc.unary_unary_rpc_method_handler(
                    servicer.ListCategories,
                    request_deserializer=strmprivacy_dot_api_dot_categories_dot_v1alpha_dot_categories__v1alpha__pb2.ListCategoriesRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_categories_dot_v1alpha_dot_categories__v1alpha__pb2.ListCategoriesResponse.SerializeToString,
            ),
            'GetCategory': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCategory,
                    request_deserializer=strmprivacy_dot_api_dot_categories_dot_v1alpha_dot_categories__v1alpha__pb2.GetCategoryRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_categories_dot_v1alpha_dot_categories__v1alpha__pb2.GetCategoryResponse.SerializeToString,
            ),
            'UpsertCategory': grpc.unary_unary_rpc_method_handler(
                    servicer.UpsertCategory,
                    request_deserializer=strmprivacy_dot_api_dot_categories_dot_v1alpha_dot_categories__v1alpha__pb2.UpsertCategoryRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_categories_dot_v1alpha_dot_categories__v1alpha__pb2.UpsertCategoryResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'strmprivacy.api.categories.v1alpha.CategoriesService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class CategoriesService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListCategories(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.categories.v1alpha.CategoriesService/ListCategories',
            strmprivacy_dot_api_dot_categories_dot_v1alpha_dot_categories__v1alpha__pb2.ListCategoriesRequest.SerializeToString,
            strmprivacy_dot_api_dot_categories_dot_v1alpha_dot_categories__v1alpha__pb2.ListCategoriesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetCategory(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.categories.v1alpha.CategoriesService/GetCategory',
            strmprivacy_dot_api_dot_categories_dot_v1alpha_dot_categories__v1alpha__pb2.GetCategoryRequest.SerializeToString,
            strmprivacy_dot_api_dot_categories_dot_v1alpha_dot_categories__v1alpha__pb2.GetCategoryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpsertCategory(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.categories.v1alpha.CategoriesService/UpsertCategory',
            strmprivacy_dot_api_dot_categories_dot_v1alpha_dot_categories__v1alpha__pb2.UpsertCategoryRequest.SerializeToString,
            strmprivacy_dot_api_dot_categories_dot_v1alpha_dot_categories__v1alpha__pb2.UpsertCategoryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/audit/v1/audit_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'strmprivacy/api/audit/v1/audit_v1.proto\x12\x18strmprivacy.api.audit.v1\x1a-strmprivacy/api/entities/v1/entities_v1.proto\x1a\x17validate/validate.proto\"\xc6\x01\n\x14GetAuditTrailRequest\x12\x46\n\nentity_ref\x18\x01 \x01(\x0b\x32\'.strmprivacy.api.entities.v1.GenericRefR\tentityRef\x12\x1b\n\tpage_size\x18\x02 \x01(\x05R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\x12*\n\nproject_id\x18\x04 \x01(\tB\x0b\xfa\x42\x08r\x06\xd0\x01\x01\xb0\x01\x01R\tprojectId\"\x87\x01\n\x15GetAuditTrailResponse\x12\x46\n\x07\x65ntries\x18\x01 \x03(\x0b\x32,.strmprivacy.api.entities.v1.AuditTrailEntryR\x07\x65ntries\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"\x82\x01\n\x1c\x43reateAuditTrailEntryRequest\x12\x62\n\x11\x61udit_trail_entry\x18\x01 \x01(\x0b\x32,.strmprivacy.api.entities.v1.AuditTrailEntryB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x0f\x61uditTrailEntry\"y\n\x1d\x43reateAuditTrailEntryResponse\x12X\n\x11\x61udit_trail_entry\x18\x01 \x01(\x0b\x32,.strmprivacy.api.entities.v1.AuditTrailEntryR\x0f\x61uditTrailEntry2\x8b\x02\n\x0c\x41uditService\x12p\n\rGetAuditTrail\x12..strmprivacy.api.audit.v1.GetAuditTrailRequest\x1a/.strmprivacy.api.audit.v1.GetAuditTrailResponse\x12\x88\x01\n\x15\x43reateAuditTrailEntry\x12\x36.strmprivacy.api.audit.v1.CreateAuditTrailEntryRequest\x1a\x37.strmprivacy.api.audit.v1.CreateAuditTrailEntryResponseB`\n\x1bio.strmprivacy.api.audit.v1P\x01Z?github.com/strmprivacy/api-definitions-go/v3/api/audit/v1;auditb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.audit.v1.audit_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033io.strmprivacy.api.audit.v1P\001Z?github.com/strmprivacy/api-definitions-go/v3/api/audit/v1;audit'
  _GETAUDITTRAILREQUEST.fields_by_name['project_id']._options = None
  _GETAUDITTRAILREQUEST.fields_by_name['project_id']._serialized_options = b'\372B\010r\006\320\001\001\260\001\001'
  _CREATEAUDITTRAILENTRYREQUEST.fields_by_name['audit_trail_entry']._options = None
  _CREATEAUDITTRAILENTRYREQUEST.fields_by_name['audit_trail_entry']._serialized_options = b'\372B\005\212\001\002\020\001'
  _GETAUDITTRAILREQUEST._serialized_start=142
  _GETAUDITTRAILREQUEST._serialized_end=340
  _GETAUDITTRAILRESPONSE._serialized_start=343
  _GETAUDITTRAILRESPONSE._serialized_end=478
  _CREATEAUDITTRAILENTRYREQUEST._serialized_start=481
  _CREATEAUDITTRAILENTRYREQUEST._serialized_end=611
  _CREATEAUDITTRAILENTRYRESPONSE._serialized_start=613
  _CREATEAUDITTRAILENTRYRESPONSE._serialized_end=734
  _AUDITSERVICE._serialized_start=737
  _AUDITSERVICE._serialized_end=1004
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/paging/v1/paging_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)strmprivacy/api/paging/v1/paging_v1.proto\x12\x19strmprivacy.api.paging.v1\"2\n\x12TimestampPageToken\x12\x1c\n\ttimestamp\x18\x01 \x01(\tR\ttimestamp\")\n\x0fOffsetPageToken\x12\x16\n\x06offset\x18\x01 \x01(\x03R\x06offset\"\xa5\x03\n\x15\x46ieldsOffsetPageToken\x12T\n\x06\x66ields\x18\x01 \x03(\x0b\x32<.strmprivacy.api.paging.v1.FieldsOffsetPageToken.FieldsEntryR\x06\x66ields\x1aw\n\x0b\x46ieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12R\n\x05value\x18\x02 \x01(\x0b\x32<.strmprivacy.api.paging.v1.FieldsOffsetPageToken.FieldOffsetR\x05value:\x02\x38\x01\x1a\x83\x01\n\x0b\x46ieldOffset\x12\x1d\n\nlast_value\x18\x01 \x01(\tR\tlastValue\x12U\n\x08ordering\x18\x02 \x01(\x0e\x32\x39.strmprivacy.api.paging.v1.FieldsOffsetPageToken.OrderingR\x08ordering\"7\n\x08Ordering\x12\x18\n\x14ORDERING_UNSPECIFIED\x10\x00\x12\x07\n\x03\x41SC\x10\x01\x12\x08\n\x04\x44\x45SC\x10\x02\x42\x63\n\x1cio.strmprivacy.api.paging.v1P\x01ZAgithub.com/strmprivacy/api-definitions-go/v3/api/paging/v1;pagingb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.paging.v1.paging_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\034io.strmprivacy.api.paging.v1P\001ZAgithub.com/strmprivacy/api-definitions-go/v3/api/paging/v1;paging'
  _FIELDSOFFSETPAGETOKEN_FIELDSENTRY._options = None
  _FIELDSOFFSETPAGETOKEN_FIELDSENTRY._serialized_options = b'8\001'
  _TIMESTAMPPAGETOKEN._serialized_start=72
  _TIMESTAMPPAGETOKEN._serialized_end=122
  _OFFSETPAGETOKEN._serialized_start=124
  _OFFSETPAGETOKEN._serialized_end=165
  _FIELDSOFFSETPAGETOKEN._serialized_start=168
  _FIELDSOFFSETPAGETOKEN._serialized_end=589
  _FIELDSOFFSETPAGETOKEN_FIELDSENTRY._serialized_start=279
  _FIELDSOFFSETPAGETOKEN_FIELDSENTRY._serialized_end=398
  _FIELDSOFFSETPAGETOKEN_FIELDOFFSET._serialized_start=401
  _FIELDSOFFSETPAGETOKEN_FIELDOFFSET._serialized_end=532
  _FIELDSOFFSETPAGETOKEN_ORDERING._serialized_start=534
  _FIELDSOFFSETPAGETOKEN_ORDERING._serialized_end=589
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/project_plans/v1alpha/project_plans_v1alpha.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from strmprivacy.api.entities.v1alpha import entities_v1alpha_pb2 as strmprivacy_dot_api_dot_entities_dot_v1alpha_dot_entities__v1alpha__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAstrmprivacy/api/project_plans/v1alpha/project_plans_v1alpha.proto\x12%strmprivacy.api.project_plans.v1alpha\x1a\x1fgoogle/api/field_behavior.proto\x1a\x37strmprivacy/api/entities/v1alpha/entities_v1alpha.proto\x1a\x17validate/validate.proto\"x\n\x17ListProjectPlansRequest\x12#\n\x0bis_template\x18\x01 \x01(\x08\x42\x02\x18\x01R\nisTemplate\x12\x38\n\x16include_dummy_template\x18\x02 \x01(\x08\x42\x02\x18\x01R\x14includeDummyTemplate\"n\n\x18ListProjectPlansResponse\x12R\n\rproject_plans\x18\x01 \x03(\x0b\x32-.strmprivacy.api.entities.v1alpha.ProjectPlanR\x0cprojectPlans\"@\n\x15GetProjectPlanRequest\x12\'\n\nproject_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01R\tprojectId\"o\n\x16GetProjectPlanResponse\x12U\n\x0cproject_plan\x18\x01 \x01(\x0b\x32-.strmprivacy.api.entities.v1alpha.ProjectPlanB\x03\xe0\x41\x02R\x0bprojectPlan\"q\n\x18UpsertProjectPlanRequest\x12U\n\x0cproject_plan\x18\x01 \x01(\x0b\x32-.strmprivacy.api.entities.v1alpha.ProjectPlanB\x03\xe0\x41\x02R\x0bprojectPlan\"r\n\x19UpsertProjectPlanResponse\x12U\n\x0cproject_plan\x18\x01 \x01(\x0b\x32-.strmprivacy.api.entities.v1alpha.ProjectPlanB\x03\xe0\x41\x02R\x0bprojectPlan\">\n\x18\x44\x65leteProjectPlanRequest\x12\"\n\nproject_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\tprojectId\"\x1b\n\x19\x44\x65leteProjectPlanResponse\"\xd6\x01\n\x17\x42uildProjectPlanRequest\x12\x41\n\x18project_plan_template_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01R\x15projectPlanTemplateId\x12*\n\nproject_id\x18\x02 \x01(\tB\x0b\xfa\x42\x08r\x06\xd0\x01\x01\xb0\x01\x01R\tprojectId\x12#\n\rvalidate_only\x18\x03 \x01(\x08R\x0cvalidateOnly\x12\'\n\x0f\x61llow_overwrite\x18\x04 \x01(\x08R\x0e\x61llowOverwrite\"l\n\x18\x42uildProjectPlanResponse\x12P\n\x0cproject_plan\x18\x01 \x01(\x0b\x32-.strmprivacy.api.entities.v1alpha.ProjectPlanR\x0bprojectPlan\"\xda\x01\n&BuildProjectPlanFromTemplateIdsRequest\x12\x39\n\x11\x66orm_template_ids\x18\x01 \x03(\tB\r\xfa\x42\n\x92\x01\x07\"\x05r\x03\xb0\x01\x01R\x0f\x66ormTemplateIds\x12\'\n\nproject_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01R\tprojectId\x12#\n\rvalidate_only\x18\x03 \x01(\x08R\x0cvalidateOnly\x12\'\n\x0f\x61llow_overwrite\x18\x04 \x01(\x08R\x0e\x61llowOverwrite\"{\n\'BuildProjectPlanFromTemplateIdsResponse\x12P\n\x0cproject_plan\x18\x01 \x01(\x0b\x32-.strmprivacy.api.entities.v1alpha.ProjectPlanR\x0bprojectPlan2\xc6\x07\n\x13ProjectPlansService\x12\x93\x01\n\x10ListProjectPlans\x12>.strmprivacy.api.project_plans.v1alpha.ListProjectPlansRequest\x1a?.strmprivacy.api.project_plans.v1alpha.ListProjectPlansResponse\x12\x8d\x01\n\x0eGetProjectPlan\x12<.strmprivacy.api.project_plans.v1alpha.GetProjectPlanRequest\x1a=.strmprivacy.api.project_plans.v1alpha.GetProjectPlanResponse\x12\x96\x01\n\x11UpsertProjectPlan\x12?.strmprivacy.api.project_plans.v1alpha.UpsertProjectPlanRequest\x1a@.strmprivacy.api.project_plans.v1alpha.UpsertProjectPlanResponse\x12\x96\x01\n\x11\x44\x65leteProjectPlan\x12?.strmprivacy.api.project_plans.v1alpha.DeleteProjectPlanRequest\x1a@.strmprivacy.api.project_plans.v1alpha.DeleteProjectPlanResponse\x12\x93\x01\n\x10\x42uildProjectPlan\x12>.strmprivacy.api.project_plans.v1alpha.BuildProjectPlanRequest\x1a?.strmprivacy.api.project_plans.v1alpha.BuildProjectPlanResponse\x12\xc0\x01\n\x1f\x42uildProjectPlanFromTemplateIds\x12M.strmprivacy.api.project_plans.v1alpha.BuildProjectPlanFromTemplateIdsRequest\x1aN.strmprivacy.api.project_plans.v1alpha.BuildProjectPlanFromTemplateIdsResponseB\x82\x01\n(io.strmprivacy.api.project_plans.v1alphaP\x01ZTgithub.com/strmprivacy/api-definitions-go/v3/api/project_plans/v1alpha;project_plansb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.project_plans.v1alpha.project_plans_v1alpha_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n(io.strmprivacy.api.project_plans.v1alphaP\001ZTgithub.com/strmprivacy/api-definitions-go/v3/api/project_plans/v1alpha;project_plans'
  _LISTPROJECTPLANSREQUEST.fields_by_name['is_template']._options = None
  _LISTPROJECTPLANSREQUEST.fields_by_name['is_template']._serialized_options = b'\030\001'
  _LISTPROJECTPLANSREQUEST.fields_by_name['include_dummy_template']._options = None
  _LISTPROJECTPLANSREQUEST.fields_by_name['include_dummy_template']._serialized_options = b'\030\001'
  _GETPROJECTPLANREQUEST.fields_by_name['project_id']._options = None
  _GETPROJECTPLANREQUEST.fields_by_name['project_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _GETPROJECTPLANRESPONSE.fields_by_name['project_plan']._options = None
  _GETPROJECTPLANRESPONSE.fields_by_name['project_plan']._serialized_options = b'\340A\002'
  _UPSERTPROJECTPLANREQUEST.fields_by_name['project_plan']._options = None
  _UPSERTPROJECTPLANREQUEST.fields_by_name['project_plan']._serialized_options = b'\340A\002'
  _UPSERTPROJECTPLANRESPONSE.fields_by_name['project_plan']._options = None
  _UPSERTPROJECTPLANRESPONSE.fields_by_name['project_plan']._serialized_options = b'\340A\002'
  _DELETEPROJECTPLANREQUEST.fields_by_name['project_id']._options = None
  _DELETEPROJECTPLANREQUEST.fields_by_name['project_id']._serialized_options = b'\340A\002'
  _BUILDPROJECTPLANREQUEST.fields_by_name['project_plan_template_id']._options = None
  _BUILDPROJECTPLANREQUEST.fields_by_name['project_plan_template_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _BUILDPROJECTPLANREQUEST.fields_by_name['project_id']._options = None
  _BUILDPROJECTPLANREQUEST.fields_by_name['project_id']._serialized_options = b'\372B\010r\006\320\001\001\260\001\001'
  _BUILDPROJECTPLANFROMTEMPLATEIDSREQUEST.fields_by_name['form_template_ids']._options = None
  _BUILDPROJECTPLANFROMTEMPLATEIDSREQUEST.fields_by_name['form_template_ids']._serialized_options = b'\372B\n\222\001\007\"\005r\003\260\001\001'
  _BUILDPROJECTPLANFROMTEMPLATEIDSREQUEST.fields_by_name['project_id']._options = None
  _BUILDPROJECTPLANFROMTEMPLATEIDSREQUEST.fields_by_name['project_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _LISTPROJECTPLANSREQUEST._serialized_start=223
  _LISTPROJECTPLANSREQUEST._serialized_end=343
  _LISTPROJECTPLANSRESPONSE._serialized_start=345
  _LISTPROJECTPLANSRESPONSE._serialized_end=455
  _GETPROJECTPLANREQUEST._serialized_start=457
  _GETPROJECTPLANREQUEST._serialized_end=521
  _GETPROJECTPLANRESPONSE._serialized_start=523
  _GETPROJECTPLANRESPONSE._serialized_end=634
  _UPSERTPROJECTPLANREQUEST._serialized_start=636
  _UPSERTPROJECTPLANREQUEST._serialized_end=749
  _UPSERTPROJECTPLANRESPONSE._serialized_start=751
  _UPSERTPROJECTPLANRESPONSE._serialized_end=865
  _DELETEPROJECTPLANREQUEST._serialized_start=867
  _DELETEPROJECTPLANREQUEST._serialized_end=929
  _DELETEPROJECTPLANRESPONSE._serialized_start=931
  _DELETEPROJECTPLANRESPONSE._serialized_end=958
  _BUILDPROJECTPLANREQUEST._serialized_start=961
  _BUILDPROJECTPLANREQUEST._serialized_end=1175
  _BUILDPROJECTPLANRESPONSE._serialized_start=1177
  _BUILDPROJECTPLANRESPONSE._serialized_end=1285
  _BUILDPROJECTPLANFROMTEMPLATEIDSREQUEST._serialized_start=1288
  _BUILDPROJECTPLANFROMTEMPLATEIDSREQUEST._serialized_end=1506
  _BUILDPROJECTPLANFROMTEMPLATEIDSRESPONSE._serialized_start=1508
  _BUILDPROJECTPLANFROMTEMPLATEIDSRESPONSE._serialized_end=1631
  _PROJECTPLANSSERVICE._serialized_start=1634
  _PROJECTPLANSSERVICE._serialized_end=2600
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/data_assets/v1alpha/data_assets_v1alpha.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from strmprivacy.api.entities.v1alpha import entities_v1alpha_pb2 as strmprivacy_dot_api_dot_entities_dot_v1alpha_dot_entities__v1alpha__pb2
from strmprivacy.api.paging.v1alpha import paging_v1alpha_pb2 as strmprivacy_dot_api_dot_paging_dot_v1alpha_dot_paging__v1alpha__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=strmprivacy/api/data_assets/v1alpha/data_assets_v1alpha.proto\x12#strmprivacy.api.data_assets.v1alpha\x1a\x37strmprivacy/api/entities/v1alpha/entities_v1alpha.proto\x1a\x33strmprivacy/api/paging/v1alpha/paging_v1alpha.proto\x1a\x17validate/validate.proto\"^\n\x15ListDataAssetsRequest\x12\x45\n\tpage_info\x18\x01 \x01(\x0b\x32(.strmprivacy.api.paging.v1alpha.PageInfoR\x08pageInfo\"\xad\x01\n\x16ListDataAssetsResponse\x12L\n\x0b\x64\x61ta_assets\x18\x01 \x03(\x0b\x32+.strmprivacy.api.entities.v1alpha.DataAssetR\ndataAssets\x12\x45\n\tpage_info\x18\x02 \x01(\x0b\x32(.strmprivacy.api.paging.v1alpha.PageInfoR\x08pageInfo\"/\n\x13GetDataAssetRequest\x12\x18\n\x02id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01R\x02id\"b\n\x14GetDataAssetResponse\x12J\n\ndata_asset\x18\x01 \x01(\x0b\x32+.strmprivacy.api.entities.v1alpha.DataAssetR\tdataAsset\"d\n\x16UpsertDataAssetRequest\x12J\n\ndata_asset\x18\x01 \x01(\x0b\x32+.strmprivacy.api.entities.v1alpha.DataAssetR\tdataAsset\"e\n\x17UpsertDataAssetResponse\x12J\n\ndata_asset\x18\x01 \x01(\x0b\x32+.strmprivacy.api.entities.v1alpha.DataAssetR\tdataAsset2\xb4\x03\n\x11\x44\x61taAssetsService\x12\x89\x01\n\x0eListDataAssets\x12:.strmprivacy.api.data_assets.v1alpha.ListDataAssetsRequest\x1a;.strmprivacy.api.data_assets.v1alpha.ListDataAssetsResponse\x12\x83\x01\n\x0cGetDataAsset\x12\x38.strmprivacy.api.data_assets.v1alpha.GetDataAssetRequest\x1a\x39.strmprivacy.api.data_assets.v1alpha.GetDataAssetResponse\x12\x8c\x01\n\x0fUpsertDataAsset\x12;.strmprivacy.api.data_assets.v1alpha.UpsertDataAssetRequest\x1a<.strmprivacy.api.data_assets.v1alpha.UpsertDataAssetResponseB|\n&io.strmprivacy.api.data_assets.v1alphaP\x01ZPgithub.com/strmprivacy/api-definitions-go/v3/api/data_assets/v1alpha;data_assetsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.data_assets.v1alpha.data_assets_v1alpha_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n&io.strmprivacy.api.data_assets.v1alphaP\001ZPgithub.com/strmprivacy/api-definitions-go/v3/api/data_assets/v1alpha;data_assets'
  _GETDATAASSETREQUEST.fields_by_name['id']._options = None
  _GETDATAASSETREQUEST.fields_by_name['id']._serialized_options = b'\372B\005r\003\260\001\001'
  _LISTDATAASSETSREQUEST._serialized_start=237
  _LISTDATAASSETSREQUEST._serialized_end=331
  _LISTDATAASSETSRESPONSE._serialized_start=334
  _LISTDATAASSETSRESPONSE._serialized_end=507
  _GETDATAASSETREQUEST._serialized_start=509
  _GETDATAASSETREQUEST._serialized_end=556
  _GETDATAASSETRESPONSE._serialized_start=558
  _GETDATAASSETRESPONSE._serialized_end=656
  _UPSERTDATAASSETREQUEST._serialized_start=658
  _UPSERTDATAASSETREQUEST._serialized_end=758
  _UPSERTDATAASSETRESPONSE._serialized_start=760
  _UPSERTDATAASSETRESPONSE._serialized_end=861
  _DATAASSETSSERVICE._serialized_start=864
  _DATAASSETSSERVICE._serialized_end=1300
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from strmprivacy.api.data_assets.v1alpha import data_assets_v1alpha_pb2 as strmprivacy_dot_api_dot_data__assets_dot_v1alpha_dot_data__assets__v1alpha__pb2


class DataAssetsServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListDataAssets = channel.unary_unary(
                '/strmprivacy.api.data_assets.v1alpha.DataAssetsService/ListDataAssets',
                request_serializer=strmprivacy_dot_api_dot_data__assets_dot_v1alpha_dot_data__assets__v1alpha__pb2.ListDataAssetsRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_data__assets_dot_v1alpha_dot_data__assets__v1alpha__pb2.ListDataAssetsResponse.FromString,
                )
        self.GetDataAsset = channel.unary_unary(
                '/strmprivacy.api.data_assets.v1alpha.DataAssetsService/GetDataAsset',
                request_serializer=strmprivacy_dot_api_dot_data__assets_dot_v1alpha_dot_data__assets__v1alpha__pb2.GetDataAssetRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_data__assets_dot_v1alpha_dot_data__assets__v1alpha__pb2.GetDataAssetResponse.FromString,
                )
        self.UpsertDataAsset = channel.unary_unary(
                '/strmprivacy.api.data_assets.v1alpha.DataAssetsService/UpsertDataAsset',
                request_serializer=strmprivacy_dot_api_dot_data__assets_dot_v1alpha_dot_data__assets__v1alpha__pb2.UpsertDataAssetRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_data__assets_dot_v1alpha_dot_data__assets__v1alpha__pb2.UpsertDataAssetResponse.FromString,
                )


class DataAssetsServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListDataAssets(self, request, context):
        """List all data assets for an organization. The organization is derived from the calling user.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDataAsset(self, request, context):
        """Get a data asset by its id.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpsertDataAsset(self, request, context):
        """Create or update a data asset.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DataAssetsServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListDataAssets': grpc.unary_unary_rpc_method_handler(
                    servicer.ListDataAssets,
                    request_deserializer=strmprivacy_dot_api_dot_data__assets_dot_v1alpha_dot_data__assets__v1alpha__pb2.ListDataAssetsRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_data__assets_dot_v1alpha_dot_data__assets__v1alpha__pb2.ListDataAssetsResponse.SerializeToString,
            ),
            'GetDataAsset': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDataAsset,
                    request_deserializer=strmprivacy_dot_api_dot_data__assets_dot_v1alpha_dot_data__assets__v1alpha__pb2.GetDataAssetRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_data__assets_dot_v1alpha_dot_data__assets__v1alpha__pb2.GetDataAssetResponse.SerializeToString,
            ),
            'UpsertDataAsset': grpc.unary_unary_rpc_method_handler(
                    servicer.UpsertDataAsset,
                    request_deserializer=strmprivacy_dot_api_dot_data__assets_dot_v1alpha_dot_data__assets__v1alpha__pb2.UpsertDataAssetRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_data__assets_dot_v1alpha_dot_data__assets__v1alpha__pb2.UpsertDataAssetResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'strmprivacy.api.data_assets.v1alpha.DataAssetsService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class DataAssetsService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListDataAssets(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.data_assets.v1alpha.DataAssetsService/ListDataAssets',
            strmprivacy_dot_api_dot_data__assets_dot_v1alpha_dot_data__assets__v1alpha__pb2.ListDataAssetsRequest.SerializeToString,
            strmprivacy_dot_api_dot_data__assets_dot_v1alpha_dot_data__assets__v1alpha__pb2.ListDataAssetsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDataAsset(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.data_assets.v1alpha.DataAssetsService/GetDataAsset',
            strmprivacy_dot_api_dot_data__assets_dot_v1alpha_dot_data__assets__v1alpha__pb2.GetDataAssetRequest.SerializeToString,
            strmprivacy_dot_api_dot_data__assets_dot_v1alpha_dot_data__assets__v1alpha__pb2.GetDataAssetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpsertDataAsset(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.data_assets.v1alpha.DataAssetsService/UpsertDataAsset',
            strmprivacy_dot_api_dot_data__assets_dot_v1alpha_dot_data__assets__v1alpha__pb2.UpsertDataAssetRequest.SerializeToString,
            strmprivacy_dot_api_dot_data__assets_dot_v1alpha_dot_data__assets__v1alpha__pb2.UpsertDataAssetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/entities/v1alpha/entities_v1alpha.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from validate import validate_pb2 as validate_dot_validate__pb2
from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7strmprivacy/api/entities/v1alpha/entities_v1alpha.proto\x12 strmprivacy.api.entities.v1alpha\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17validate/validate.proto\x1a-strmprivacy/api/entities/v1/entities_v1.proto\"y\n\x0bProjectPlan\x12\'\n\nproject_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01R\tprojectId\x12\x41\n\x07\x65ntries\x18\x02 \x03(\x0b\x32\'.strmprivacy.api.entities.v1alpha.EntryR\x07\x65ntries\"\xba\x03\n\x0c\x46ormTemplate\x12\x18\n\x02id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01R\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x31\n\x0forganization_id\x18\x03 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01R\x0eorganizationId\x12Z\n\x05items\x18\x04 \x03(\x0b\x32\x44.strmprivacy.api.entities.v1alpha.FormTemplate.EntryOrFormTemplateIdR\x05items\x12*\n\x11is_project_intake\x18\x05 \x01(\x08R\x0fisProjectIntake\x1a\xc0\x01\n\x15\x45ntryOrFormTemplateId\x12^\n\rform_template\x18\x01 \x01(\x0b\x32\x37.strmprivacy.api.entities.v1alpha.FormTemplateReferenceH\x00R\x0c\x66ormTemplate\x12?\n\x05\x65ntry\x18\x02 \x01(\x0b\x32\'.strmprivacy.api.entities.v1alpha.EntryH\x00R\x05\x65ntryB\x06\n\x04part\"V\n\x15\x46ormTemplateReference\x12\x18\n\x02id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01R\x02id\x12#\n\rrender_inline\x18\x02 \x01(\x08R\x0crenderInline\"\xbb\x19\n\x05\x45ntry\x12\x1b\n\x02id\x18\x01 \x01(\tB\x0b\xfa\x42\x08r\x06\xd0\x01\x01\xb0\x01\x01R\x02id\x12\x1e\n\x04name\x18\x02 \x01(\tB\n\xfa\x42\x07r\x05\x18\x64\xd0\x01\x01R\x04name\x12%\n\x07\x63ontent\x18\x03 \x01(\tB\x0b\xfa\x42\x08r\x06\x18\x88\'\xd0\x01\x01R\x07\x63ontent\x12?\n\rcreation_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0c\x63reationTime\x12\x35\n\x08\x64ue_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x07\x64ueTime\x12\x43\n\x0f\x63ompletion_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0e\x63ompletionTime\x12;\n\x07\x63reator\x18\x07 \x01(\x0b\x32!.strmprivacy.api.entities.v1.UserR\x07\x63reator\x12=\n\x08\x61ssignee\x18\x08 \x01(\x0b\x32!.strmprivacy.api.entities.v1.UserR\x08\x61ssignee\x12\x1b\n\thelp_text\x18\t \x01(\tR\x08helpText\x12\x16\n\x06remark\x18\n \x01(\tR\x06remark\x12$\n\x0e\x63\x61n_be_deleted\x18\x0b \x01(\x08R\x0c\x63\x61nBeDeleted\x12\x35\n\x10\x66orm_template_id\x18\x0c \x01(\tB\x0b\xfa\x42\x08r\x06\xd0\x01\x01\xb0\x01\x01R\x0e\x66ormTemplateId\x12\x42\n\x04task\x18\r \x01(\x0b\x32,.strmprivacy.api.entities.v1alpha.Entry.TaskH\x00R\x04task\x12[\n\rdata_contract\x18\x0e \x01(\x0b\x32\x34.strmprivacy.api.entities.v1alpha.Entry.DataContractH\x00R\x0c\x64\x61taContract\x12N\n\x08\x64ocument\x18\x0f \x01(\x0b\x32\x30.strmprivacy.api.entities.v1alpha.Entry.DocumentH\x00R\x08\x64ocument\x12N\n\x08pipeline\x18\x10 \x01(\x0b\x32\x30.strmprivacy.api.entities.v1alpha.Entry.PipelineH\x00R\x08pipeline\x12N\n\x08question\x18\x11 \x01(\x0b\x32\x30.strmprivacy.api.entities.v1alpha.Entry.QuestionH\x00R\x08question\x12V\n\x07\x63hoices\x18\x12 \x01(\x0b\x32:.strmprivacy.api.entities.v1alpha.Entry.MultipleChoiceItemH\x00R\x07\x63hoices\x12\x14\n\x04html\x18\x13 \x01(\tH\x00R\x04html\x12X\n\x0csection_open\x18\x14 \x01(\x0b\x32\x33.strmprivacy.api.entities.v1alpha.Entry.SectionOpenH\x00R\x0bsectionOpen\x12[\n\rsection_close\x18\x15 \x01(\x0b\x32\x34.strmprivacy.api.entities.v1alpha.Entry.SectionCloseH\x00R\x0csectionClose\x12Y\n\radd_one_entry\x18m \x01(\x0b\x32\x33.strmprivacy.api.entities.v1alpha.Entry.AddOneEntryH\x00R\x0b\x61\x64\x64OneEntry\x1a\x99\x04\n\x0b\x41\x64\x64OneEntry\x12\x42\n\x04task\x18\x01 \x01(\x0b\x32,.strmprivacy.api.entities.v1alpha.Entry.TaskH\x00R\x04task\x12[\n\rdata_contract\x18\x02 \x01(\x0b\x32\x34.strmprivacy.api.entities.v1alpha.Entry.DataContractH\x00R\x0c\x64\x61taContract\x12N\n\x08\x64ocument\x18\x03 \x01(\x0b\x32\x30.strmprivacy.api.entities.v1alpha.Entry.DocumentH\x00R\x08\x64ocument\x12N\n\x08pipeline\x18\x04 \x01(\x0b\x32\x30.strmprivacy.api.entities.v1alpha.Entry.PipelineH\x00R\x08pipeline\x12N\n\x08question\x18\x05 \x01(\x0b\x32\x30.strmprivacy.api.entities.v1alpha.Entry.QuestionH\x00R\x08question\x12V\n\x07\x63hoices\x18\x06 \x01(\x0b\x32:.strmprivacy.api.entities.v1alpha.Entry.MultipleChoiceItemH\x00R\x07\x63hoices\x12\x14\n\x04html\x18\x07 \x01(\tH\x00R\x04htmlB\x0b\n\x04type\x12\x03\xf8\x42\x01\x1a\x06\n\x04Task\x1aX\n\x0c\x44\x61taContract\x12H\n\x03ref\x18\x02 \x01(\x0b\x32,.strmprivacy.api.entities.v1.DataContractRefB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x03ref\x1a\x38\n\x08\x44ocument\x12\x1a\n\x08\x66ilename\x18\x02 \x01(\tR\x08\x66ilename\x12\x10\n\x03uri\x18\x03 \x01(\tR\x03uri\x1a\xa1\x01\n\x08Pipeline\x12@\n\x06stream\x18\x02 \x01(\x0b\x32&.strmprivacy.api.entities.v1.StreamRefH\x00R\x06stream\x12G\n\tbatch_job\x18\x03 \x01(\x0b\x32(.strmprivacy.api.entities.v1.BatchJobRefH\x00R\x08\x62\x61tchJobB\n\n\x08pipeline\x1a\xb9\x01\n\x08Question\x12m\n\x12\x61nswers_and_labels\x18\x01 \x03(\x0b\x32?.strmprivacy.api.entities.v1alpha.Entry.Question.AnswerAndLabelR\x10\x61nswersAndLabels\x1a>\n\x0e\x41nswerAndLabel\x12\x16\n\x06\x61nswer\x18\x01 \x01(\tR\x06\x61nswer\x12\x14\n\x05label\x18\x02 \x01(\tR\x05label\x1a\xe3\x02\n\x12MultipleChoiceItem\x12\x12\n\x04text\x18\x01 \x01(\tR\x04text\x12\x18\n\x07\x63hoices\x18\x02 \x03(\tR\x07\x63hoices\x12\x18\n\x07weights\x18\x03 \x03(\x02R\x07weights\x12\x18\n\x07\x61nswers\x18\x04 \x03(\x05R\x07\x61nswers\x12V\n\x05style\x18\x05 \x01(\x0e\x32@.strmprivacy.api.entities.v1alpha.Entry.MultipleChoiceItem.StyleR\x05style\x12L\n\x1b\x61ssociated_form_template_id\x18\x06 \x03(\tB\r\xfa\x42\n\x92\x01\x07\"\x05r\x03\xb0\x01\x01R\x18\x61ssociatedFormTemplateId\"E\n\x05Style\x12\x15\n\x11STYLE_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43HECKBOX\x10\x01\x12\x0c\n\x08\x44ROPDOWN\x10\x02\x12\t\n\x05RADIO\x10\x03\x1a\x99\x01\n\x12RiskAssessmentItem\x12\x12\n\x04risk\x18\x02 \x01(\tR\x04risk\x12\'\n\x0fharm_likelihood\x18\x03 \x01(\tR\x0eharmLikelihood\x12#\n\rharm_severity\x18\x04 \x01(\tR\x0charmSeverity\x12!\n\x0coverall_risk\x18\x05 \x01(\tR\x0boverallRisk\x1a\xbb\x01\n\x12RiskMitigationItem\x12\x12\n\x04risk\x18\x02 \x01(\tR\x04risk\x12!\n\x0coverall_risk\x18\x03 \x01(\tR\x0boverallRisk\x12-\n\x12mitigation_measure\x18\x05 \x01(\tR\x11mitigationMeasure\x12#\n\rresidual_risk\x18\x06 \x01(\tR\x0cresidualRisk\x12\x1a\n\x08\x61pproval\x18\x07 \x01(\tR\x08\x61pproval\x1aI\n\rRecordingItem\x12\x1e\n\nparticular\x18\x02 \x01(\tR\nparticular\x12\x18\n\x07remarks\x18\x04 \x01(\tR\x07remarks\x1a\x32\n\x0bSectionOpen\x12#\n\rrender_inline\x18\x01 \x01(\x08R\x0crenderInline\x1a\x0e\n\x0cSectionCloseB\x0b\n\x04item\x12\x03\xf8\x42\x01\"\xd1\x02\n\x0e\x43ontactDetails\x12P\n\x04type\x18\x01 \x01(\x0e\x32<.strmprivacy.api.entities.v1alpha.ContactDetails.ContactTypeR\x04type\x12\x1d\n\nother_type\x18\x02 \x01(\tR\totherType\x12\x12\n\x04name\x18\x03 \x01(\tR\x04name\x12\x18\n\x07\x61\x64\x64ress\x18\x04 \x01(\tR\x07\x61\x64\x64ress\x12\x14\n\x05\x65mail\x18\x05 \x01(\tR\x05\x65mail\x12\x14\n\x05phone\x18\x06 \x01(\tR\x05phone\"t\n\x0b\x43ontactType\x12\x1c\n\x18\x43ONTACT_TYPE_UNSPECIFIED\x10\x00\x12\x0b\n\x07PRIMARY\x10\x01\x12\x12\n\x0eREPRESENTATIVE\x10\x02\x12\x1b\n\x17\x44\x41TA_PROTECTION_OFFICER\x10\x03\x12\t\n\x05OTHER\x10\x04\"\xc2\x03\n\x05Party\x12\x1b\n\x02id\x18\x01 \x01(\tB\x0b\xfa\x42\x08r\x06\xd0\x01\x01\xb0\x01\x01R\x02id\x12\x1a\n\x08\x65xternal\x18\x02 \x01(\x08R\x08\x65xternal\x12\x12\n\x04name\x18\x03 \x01(\tR\x04name\x12,\n\x0bregion_code\x18\x04 \x01(\tB\x0b\xfa\x42\x08r\x06\x98\x01\x02\xd0\x01\x01R\nregionCode\x12Y\n\x0f\x63ontact_details\x18\x05 \x03(\x0b\x32\x30.strmprivacy.api.entities.v1alpha.ContactDetailsR\x0e\x63ontactDetails\x12;\n\x0bupdate_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nupdateTime\x1aI\n\x04List\x12\x41\n\x07parties\x18\x01 \x03(\x0b\x32\'.strmprivacy.api.entities.v1alpha.PartyR\x07parties\"[\n\x0cRelationType\x12\x1d\n\x19RELATION_TYPE_UNSPECIFIED\x10\x00\x12\x0e\n\nCONTROLLER\x10\x01\x12\r\n\tPROCESSOR\x10\x02\x12\r\n\tRECIPIENT\x10\x03\"\xa9\x03\n\x08\x43\x61tegory\x12\x1b\n\x02id\x18\x01 \x01(\tB\x0b\xfa\x42\x08r\x06\xd0\x01\x01\xb0\x01\x01R\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x43\n\x04type\x18\x03 \x01(\x0e\x32/.strmprivacy.api.entities.v1alpha.Category.TypeR\x04type\x12;\n\x0bupdate_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nupdateTime\x1aR\n\x04List\x12J\n\ncategories\x18\x01 \x03(\x0b\x32*.strmprivacy.api.entities.v1alpha.CategoryR\ncategories\"\x95\x01\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\x08\n\x04\x44\x41TA\x10\x01\x12\x10\n\x0c\x44\x41TA_SUBJECT\x10\x02\x12\x12\n\x0e\x44\x41TA_RECIPIENT\x10\x03\x12\x0e\n\nDATA_ASSET\x10\x04\x12\x11\n\rPERSONAL_DATA\x10\x05\x12\x0e\n\nPROCESSING\x10\x06\x12\x14\n\x10SECURITY_MEASURE\x10\x07\"\x87\x04\n\tDataAsset\x12\x1b\n\x02id\x18\x01 \x01(\tB\x0b\xfa\x42\x08r\x06\xd0\x01\x01\xb0\x01\x01R\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12J\n\ncategories\x18\x03 \x03(\x0b\x32*.strmprivacy.api.entities.v1alpha.CategoryR\ncategories\x12L\n\rhosting_party\x18\x04 \x01(\x0b\x32\'.strmprivacy.api.entities.v1alpha.PartyR\x0chostingParty\x12.\n\x13\x63ontact_person_name\x18\x05 \x01(\tR\x11\x63ontactPersonName\x12,\n\x0bregion_code\x18\x06 \x01(\tB\x0b\xfa\x42\x08r\x06\x98\x01\x02\xd0\x01\x01R\nregionCode\x12;\n\x0bupdate_time\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nupdateTime\x1aT\n\x04List\x12L\n\x0b\x64\x61ta_assets\x18\x01 \x03(\x0b\x32+.strmprivacy.api.entities.v1alpha.DataAssetR\ndataAssets\">\n\x0cRelationType\x12\x1d\n\x19RELATION_TYPE_UNSPECIFIED\x10\x00\x12\x0f\n\x0b\x44\x41TA_SOURCE\x10\x01\"\xdd\t\n\x04Ropa\x12\x34\n\x0forganization_id\x18\x01 \x01(\tB\x0b\xfa\x42\x08r\x06\xd0\x01\x01\xb0\x01\x01R\x0eorganizationId\x12G\n\x07records\x18\x02 \x03(\x0b\x32-.strmprivacy.api.entities.v1alpha.Ropa.RecordR\x07records\x1a\xd5\x08\n\x06Record\x12\x1b\n\x02id\x18\x01 \x01(\tB\x0b\xfa\x42\x08r\x06\xd0\x01\x01\xb0\x01\x01R\x02id\x12\x34\n\x0forganization_id\x18\x02 \x01(\tB\x0b\xfa\x42\x08r\x06\xd0\x01\x01\xb0\x01\x01R\x0eorganizationId\x12\x12\n\x04name\x18\x03 \x01(\tR\x04name\x12;\n\x0bupdate_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nupdateTime\x12\x42\n\x0bupdate_user\x18\x05 \x01(\x0b\x32!.strmprivacy.api.entities.v1.UserR\nupdateUser\x12\x18\n\x07version\x18\x06 \x01(\x05R\x07version\x12T\n\x07parties\x18\x07 \x03(\x0b\x32:.strmprivacy.api.entities.v1alpha.Ropa.Record.PartiesEntryR\x07parties\x12%\n\x0epurpose_levels\x18\x08 \x03(\x05R\rpurposeLevels\x12]\n\ncategories\x18\t \x03(\x0b\x32=.strmprivacy.api.entities.v1alpha.Ropa.Record.CategoriesEntryR\ncategories\x12*\n\x11\x64\x61ta_contract_ids\x18\n \x03(\tR\x0f\x64\x61taContractIds\x12^\n\x0b\x64\x61ta_assets\x18\x0b \x03(\x0b\x32=.strmprivacy.api.entities.v1alpha.Ropa.Record.DataAssetsEntryR\ndataAssets\x12\x32\n\x15\x64\x61ta_transfer_details\x18\x0c \x01(\tR\x13\x64\x61taTransferDetails\x12\x39\n\x19\x64\x61ta_retention_policy_ids\x18\r \x03(\tR\x16\x64\x61taRetentionPolicyIds\x12\'\n\x0f\x61\x64\x64itional_info\x18\x0e \x01(\tR\x0e\x61\x64\x64itionalInfo\x1ah\n\x0cPartiesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x42\n\x05value\x18\x02 \x01(\x0b\x32,.strmprivacy.api.entities.v1alpha.Party.ListR\x05value:\x02\x38\x01\x1an\n\x0f\x43\x61tegoriesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x45\n\x05value\x18\x02 \x01(\x0b\x32/.strmprivacy.api.entities.v1alpha.Category.ListR\x05value:\x02\x38\x01\x1ao\n\x0f\x44\x61taAssetsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x46\n\x05value\x18\x02 \x01(\x0b\x32\x30.strmprivacy.api.entities.v1alpha.DataAsset.ListR\x05value:\x02\x38\x01\x42s\n#io.strmprivacy.api.entities.v1alphaP\x01ZJgithub.com/strmprivacy/api-definitions-go/v3/api/entities/v1alpha;entitiesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.entities.v1alpha.entities_v1alpha_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#io.strmprivacy.api.entities.v1alphaP\001ZJgithub.com/strmprivacy/api-definitions-go/v3/api/entities/v1alpha;entities'
  _PROJECTPLAN.fields_by_name['project_id']._options = None
  _PROJECTPLAN.fields_by_name['project_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _FORMTEMPLATE.fields_by_name['id']._options = None
  _FORMTEMPLATE.fields_by_name['id']._serialized_options = b'\372B\005r\003\260\001\001'
  _FORMTEMPLATE.fields_by_name['organization_id']._options = None
  _FORMTEMPLATE.fields_by_name['organization_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _FORMTEMPLATEREFERENCE.fields_by_name['id']._options = None
  _FORMTEMPLATEREFERENCE.fields_by_name['id']._serialized_options = b'\372B\005r\003\260\001\001'
  _ENTRY_ADDONEENTRY.oneofs_by_name['type']._options = None
  _ENTRY_ADDONEENTRY.oneofs_by_name['type']._serialized_options = b'\370B\001'
  _ENTRY_DATACONTRACT.fields_by_name['ref']._options = None
  _ENTRY_DATACONTRACT.fields_by_name['ref']._serialized_options = b'\372B\005\212\001\002\020\001'
  _ENTRY_MULTIPLECHOICEITEM.fields_by_name['associated_form_template_id']._options = None
  _ENTRY_MULTIPLECHOICEITEM.fields_by_name['associated_form_template_id']._serialized_options = b'\372B\n\222\001\007\"\005r\003\260\001\001'
  _ENTRY.oneofs_by_name['item']._options = None
  _ENTRY.oneofs_by_name['item']._serialized_options = b'\370B\001'
  _ENTRY.fields_by_name['id']._options = None
  _ENTRY.fields_by_name['id']._serialized_options = b'\372B\010r\006\320\001\001\260\001\001'
  _ENTRY.fields_by_name['name']._options = None
  _ENTRY.fields_by_name['name']._serialized_options = b'\372B\007r\005\030d\320\001\001'
  _ENTRY.fields_by_name['content']._options = None
  _ENTRY.fields_by_name['content']._serialized_options = b'\372B\010r\006\030\210\'\320\001\001'
  _ENTRY.fields_by_name['form_template_id']._options = None
  _ENTRY.fields_by_name['form_template_id']._serialized_options = b'\372B\010r\006\320\001\001\260\001\001'
  _PARTY.fields_by_name['id']._options = None
  _PARTY.fields_by_name['id']._serialized_options = b'\372B\010r\006\320\001\001\260\001\001'
  _PARTY.fields_by_name['region_code']._options = None
  _PARTY.fields_by_name['region_code']._serialized_options = b'\372B\010r\006\230\001\002\320\001\001'
  _CATEGORY.fields_by_name['id']._options = None
  _CATEGORY.fields_by_name['id']._serialized_options = b'\372B\010r\006\320\001\001\260\001\001'
  _DATAASSET.fields_by_name['id']._options = None
  _DATAASSET.fields_by_name['id']._serialized_options = b'\372B\010r\006\320\001\001\260\001\001'
  _DATAASSET.fields_by_name['region_code']._options = None
  _DATAASSET.fields_by_name['region_code']._serialized_options = b'\372B\010r\006\230\001\002\320\001\001'
  _ROPA_RECORD_PARTIESENTRY._options = None
  _ROPA_RECORD_PARTIESENTRY._serialized_options = b'8\001'
  _ROPA_RECORD_CATEGORIESENTRY._options = None
  _ROPA_RECORD_CATEGORIESENTRY._serialized_options = b'8\001'
  _ROPA_RECORD_DATAASSETSENTRY._options = None
  _ROPA_RECORD_DATAASSETSENTRY._serialized_options = b'8\001'
  _ROPA_RECORD.fields_by_name['id']._options = None
  _ROPA_RECORD.fields_by_name['id']._serialized_options = b'\372B\010r\006\320\001\001\260\001\001'
  _ROPA_RECORD.fields_by_name['organization_id']._options = None
  _ROPA_RECORD.fields_by_name['organization_id']._serialized_options = b'\372B\010r\006\320\001\001\260\001\001'
  _ROPA.fields_by_name['organization_id']._options = None
  _ROPA.fields_by_name['organization_id']._serialized_options = b'\372B\010r\006\320\001\001\260\001\001'
  _PROJECTPLAN._serialized_start=198
  _PROJECTPLAN._serialized_end=319
  _FORMTEMPLATE._serialized_start=322
  _FORMTEMPLATE._serialized_end=764
  _FORMTEMPLATE_ENTRYORFORMTEMPLATEID._serialized_start=572
  _FORMTEMPLATE_ENTRYORFORMTEMPLATEID._serialized_end=764
  _FORMTEMPLATEREFERENCE._serialized_start=766
  _FORMTEMPLATEREFERENCE._serialized_end=852
  _ENTRY._serialized_start=855
  _ENTRY._serialized_end=4114
  _ENTRY_ADDONEENTRY._serialized_start=2209
  _ENTRY_ADDONEENTRY._serialized_end=2746
  _ENTRY_TASK._serialized_start=2748
  _ENTRY_TASK._serialized_end=2754
  _ENTRY_DATACONTRACT._serialized_start=2756
  _ENTRY_DATACONTRACT._serialized_end=2844
  _ENTRY_DOCUMENT._serialized_start=2846
  _ENTRY_DOCUMENT._serialized_end=2902
  _ENTRY_PIPELINE._serialized_start=2905
  _ENTRY_PIPELINE._serialized_end=3066
  _ENTRY_QUESTION._serialized_start=3069
  _ENTRY_QUESTION._serialized_end=3254
  _ENTRY_QUESTION_ANSWERANDLABEL._serialized_start=3192
  _ENTRY_QUESTION_ANSWERANDLABEL._serialized_end=3254
  _ENTRY_MULTIPLECHOICEITEM._serialized_start=3257
  _ENTRY_MULTIPLECHOICEITEM._serialized_end=3612
  _ENTRY_MULTIPLECHOICEITEM_STYLE._serialized_start=3543
  _ENTRY_MULTIPLECHOICEITEM_STYLE._serialized_end=3612
  _ENTRY_RISKASSESSMENTITEM._serialized_start=3615
  _ENTRY_RISKASSESSMENTITEM._serialized_end=3768
  _ENTRY_RISKMITIGATIONITEM._serialized_start=3771
  _ENTRY_RISKMITIGATIONITEM._serialized_end=3958
  _ENTRY_RECORDINGITEM._serialized_start=3960
  _ENTRY_RECORDINGITEM._serialized_end=4033
  _ENTRY_SECTIONOPEN._serialized_start=4035
  _ENTRY_SECTIONOPEN._serialized_end=4085
  _ENTRY_SECTIONCLOSE._serialized_start=4087
  _ENTRY_SECTIONCLOSE._serialized_end=4101
  _CONTACTDETAILS._serialized_start=4117
  _CONTACTDETAILS._serialized_end=4454
  _CONTACTDETAILS_CONTACTTYPE._serialized_start=4338
  _CONTACTDETAILS_CONTACTTYPE._serialized_end=4454
  _PARTY._serialized_start=4457
  _PARTY._serialized_end=4907
  _PARTY_LIST._serialized_start=4741
  _PARTY_LIST._serialized_end=4814
  _PARTY_RELATIONTYPE._serialized_start=4816
  _PARTY_RELATIONTYPE._serialized_end=4907
  _CATEGORY._serialized_start=4910
  _CATEGORY._serialized_end=5335
  _CATEGORY_LIST._serialized_start=5101
  _CATEGORY_LIST._serialized_end=5183
  _CATEGORY_TYPE._serialized_start=5186
  _CATEGORY_TYPE._serialized_end=5335
  _DATAASSET._serialized_start=5338
  _DATAASSET._serialized_end=5857
  _DATAASSET_LIST._serialized_start=5709
  _DATAASSET_LIST._serialized_end=5793
  _DATAASSET_RELATIONTYPE._serialized_start=5795
  _DATAASSET_RELATIONTYPE._serialized_end=5857
  _ROPA._serialized_start=5860
  _ROPA._serialized_end=7105
  _ROPA_RECORD._serialized_start=5996
  _ROPA_RECORD._serialized_end=7105
  _ROPA_RECORD_PARTIESENTRY._serialized_start=6776
  _ROPA_RECORD_PARTIESENTRY._serialized_end=6880
  _ROPA_RECORD_CATEGORIESENTRY._serialized_start=6882
  _ROPA_RECORD_CATEGORIESENTRY._serialized_end=6992
  _ROPA_RECORD_DATAASSETSENTRY._serialized_start=6994
  _ROPA_RECORD_DATAASSETSENTRY._serialized_end=7105
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/forms/v1alpha/forms_v1alpha.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from strmprivacy.api.entities.v1alpha import entities_v1alpha_pb2 as strmprivacy_dot_api_dot_entities_dot_v1alpha_dot_entities__v1alpha__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1strmprivacy/api/forms/v1alpha/forms_v1alpha.proto\x12\x1dstrmprivacy.api.forms.v1alpha\x1a\x1fgoogle/api/field_behavior.proto\x1a\x37strmprivacy/api/entities/v1alpha/entities_v1alpha.proto\x1a\x17validate/validate.proto\"\x1a\n\x18ListFormTemplatesRequest\"r\n\x19ListFormTemplatesResponse\x12U\n\x0e\x66orm_templates\x18\x01 \x03(\x0b\x32..strmprivacy.api.entities.v1alpha.FormTemplateR\rformTemplates\"2\n\x16GetFormTemplateRequest\x12\x18\n\x02id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01R\x02id\"n\n\x17GetFormTemplateResponse\x12S\n\rform_template\x18\x01 \x01(\x0b\x32..strmprivacy.api.entities.v1alpha.FormTemplateR\x0c\x66ormTemplate\"u\n\x19UpsertFormTemplateRequest\x12X\n\rform_template\x18\x01 \x01(\x0b\x32..strmprivacy.api.entities.v1alpha.FormTemplateB\x03\xe0\x41\x02R\x0c\x66ormTemplate\"v\n\x1aUpsertFormTemplateResponse\x12X\n\rform_template\x18\x01 \x01(\x0b\x32..strmprivacy.api.entities.v1alpha.FormTemplateB\x03\xe0\x41\x02R\x0c\x66ormTemplate\"0\n\x19\x44\x65leteFormTemplateRequest\x12\x13\n\x02id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x02id\"\x1c\n\x1a\x44\x65leteFormTemplateResponse2\xb2\x04\n\x0c\x46ormsService\x12\x86\x01\n\x11ListFormTemplates\x12\x37.strmprivacy.api.forms.v1alpha.ListFormTemplatesRequest\x1a\x38.strmprivacy.api.forms.v1alpha.ListFormTemplatesResponse\x12\x80\x01\n\x0fGetFormTemplate\x12\x35.strmprivacy.api.forms.v1alpha.GetFormTemplateRequest\x1a\x36.strmprivacy.api.forms.v1alpha.GetFormTemplateResponse\x12\x89\x01\n\x12UpsertFormTemplate\x12\x38.strmprivacy.api.forms.v1alpha.UpsertFormTemplateRequest\x1a\x39.strmprivacy.api.forms.v1alpha.UpsertFormTemplateResponse\x12\x89\x01\n\x12\x44\x65leteFormTemplate\x12\x38.strmprivacy.api.forms.v1alpha.DeleteFormTemplateRequest\x1a\x39.strmprivacy.api.forms.v1alpha.DeleteFormTemplateResponseBj\n io.strmprivacy.api.forms.v1alphaP\x01ZDgithub.com/strmprivacy/api-definitions-go/v3/api/forms/v1alpha;formsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.forms.v1alpha.forms_v1alpha_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n io.strmprivacy.api.forms.v1alphaP\001ZDgithub.com/strmprivacy/api-definitions-go/v3/api/forms/v1alpha;forms'
  _GETFORMTEMPLATEREQUEST.fields_by_name['id']._options = None
  _GETFORMTEMPLATEREQUEST.fields_by_name['id']._serialized_options = b'\372B\005r\003\260\001\001'
  _UPSERTFORMTEMPLATEREQUEST.fields_by_name['form_template']._options = None
  _UPSERTFORMTEMPLATEREQUEST.fields_by_name['form_template']._serialized_options = b'\340A\002'
  _UPSERTFORMTEMPLATERESPONSE.fields_by_name['form_template']._options = None
  _UPSERTFORMTEMPLATERESPONSE.fields_by_name['form_template']._serialized_options = b'\340A\002'
  _DELETEFORMTEMPLATEREQUEST.fields_by_name['id']._options = None
  _DELETEFORMTEMPLATEREQUEST.fields_by_name['id']._serialized_options = b'\340A\002'
  _LISTFORMTEMPLATESREQUEST._serialized_start=199
  _LISTFORMTEMPLATESREQUEST._serialized_end=225
  _LISTFORMTEMPLATESRESPONSE._serialized_start=227
  _LISTFORMTEMPLATESRESPONSE._serialized_end=341
  _GETFORMTEMPLATEREQUEST._serialized_start=343
  _GETFORMTEMPLATEREQUEST._serialized_end=393
  _GETFORMTEMPLATERESPONSE._serialized_start=395
  _GETFORMTEMPLATERESPONSE._serialized_end=505
  _UPSERTFORMTEMPLATEREQUEST._serialized_start=507
  _UPSERTFORMTEMPLATEREQUEST._serialized_end=624
  _UPSERTFORMTEMPLATERESPONSE._serialized_start=626
  _UPSERTFORMTEMPLATERESPONSE._serialized_end=744
  _DELETEFORMTEMPLATEREQUEST._serialized_start=746
  _DELETEFORMTEMPLATEREQUEST._serialized_end=794
  _DELETEFORMTEMPLATERESPONSE._serialized_start=796
  _DELETEFORMTEMPLATERESPONSE._serialized_end=824
  _FORMSSERVICE._serialized_start=827
  _FORMSSERVICE._serialized_end=1389
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/parties/v1alpha/parties_v1alpha.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from strmprivacy.api.entities.v1alpha import entities_v1alpha_pb2 as strmprivacy_dot_api_dot_entities_dot_v1alpha_dot_entities__v1alpha__pb2
from strmprivacy.api.paging.v1alpha import paging_v1alpha_pb2 as strmprivacy_dot_api_dot_paging_dot_v1alpha_dot_paging__v1alpha__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5strmprivacy/api/parties/v1alpha/parties_v1alpha.proto\x12\x1fstrmprivacy.api.parties.v1alpha\x1a\x37strmprivacy/api/entities/v1alpha/entities_v1alpha.proto\x1a\x33strmprivacy/api/paging/v1alpha/paging_v1alpha.proto\x1a\x17validate/validate.proto\"[\n\x12ListPartiesRequest\x12\x45\n\tpage_info\x18\x01 \x01(\x0b\x32(.strmprivacy.api.paging.v1alpha.PageInfoR\x08pageInfo\"\x9f\x01\n\x13ListPartiesResponse\x12\x41\n\x07parties\x18\x01 \x03(\x0b\x32\'.strmprivacy.api.entities.v1alpha.PartyR\x07parties\x12\x45\n\tpage_info\x18\x02 \x01(\x0b\x32(.strmprivacy.api.paging.v1alpha.PageInfoR\x08pageInfo\"+\n\x0fGetPartyRequest\x12\x18\n\x02id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01R\x02id\"Q\n\x10GetPartyResponse\x12=\n\x05party\x18\x01 \x01(\x0b\x32\'.strmprivacy.api.entities.v1alpha.PartyR\x05party\"S\n\x12UpsertPartyRequest\x12=\n\x05party\x18\x01 \x01(\x0b\x32\'.strmprivacy.api.entities.v1alpha.PartyR\x05party\"T\n\x13UpsertPartyResponse\x12=\n\x05party\x18\x01 \x01(\x0b\x32\'.strmprivacy.api.entities.v1alpha.PartyR\x05party2\xf5\x02\n\x0ePartiesService\x12x\n\x0bListParties\x12\x33.strmprivacy.api.parties.v1alpha.ListPartiesRequest\x1a\x34.strmprivacy.api.parties.v1alpha.ListPartiesResponse\x12o\n\x08GetParty\x12\x30.strmprivacy.api.parties.v1alpha.GetPartyRequest\x1a\x31.strmprivacy.api.parties.v1alpha.GetPartyResponse\x12x\n\x0bUpsertParty\x12\x33.strmprivacy.api.parties.v1alpha.UpsertPartyRequest\x1a\x34.strmprivacy.api.parties.v1alpha.UpsertPartyResponseBp\n\"io.strmprivacy.api.parties.v1alphaP\x01ZHgithub.com/strmprivacy/api-definitions-go/v3/api/parties/v1alpha;partiesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.parties.v1alpha.parties_v1alpha_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\"io.strmprivacy.api.parties.v1alphaP\001ZHgithub.com/strmprivacy/api-definitions-go/v3/api/parties/v1alpha;parties'
  _GETPARTYREQUEST.fields_by_name['id']._options = None
  _GETPARTYREQUEST.fields_by_name['id']._serialized_options = b'\372B\005r\003\260\001\001'
  _LISTPARTIESREQUEST._serialized_start=225
  _LISTPARTIESREQUEST._serialized_end=316
  _LISTPARTIESRESPONSE._serialized_start=319
  _LISTPARTIESRESPONSE._serialized_end=478
  _GETPARTYREQUEST._serialized_start=480
  _GETPARTYREQUEST._serialized_end=523
  _GETPARTYRESPONSE._serialized_start=525
  _GETPARTYRESPONSE._serialized_end=606
  _UPSERTPARTYREQUEST._serialized_start=608
  _UPSERTPARTYREQUEST._serialized_end=691
  _UPSERTPARTYRESPONSE._serialized_start=693
  _UPSERTPARTYRESPONSE._serialized_end=777
  _PARTIESSERVICE._serialized_start=780
  _PARTIESSERVICE._serialized_end=1153
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/ropa/v1alpha/ropa_v1alpha.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2
from strmprivacy.api.paging.v1alpha import paging_v1alpha_pb2 as strmprivacy_dot_api_dot_paging_dot_v1alpha_dot_paging__v1alpha__pb2
from validate import validate_pb2 as validate_dot_validate__pb2
from strmprivacy.api.entities.v1alpha import entities_v1alpha_pb2 as strmprivacy_dot_api_dot_entities_dot_v1alpha_dot_entities__v1alpha__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/strmprivacy/api/ropa/v1alpha/ropa_v1alpha.proto\x12\x1cstrmprivacy.api.ropa.v1alpha\x1a-strmprivacy/api/entities/v1/entities_v1.proto\x1a\x33strmprivacy/api/paging/v1alpha/paging_v1alpha.proto\x1a\x17validate/validate.proto\x1a\x37strmprivacy/api/entities/v1alpha/entities_v1alpha.proto\"W\n\x0eGetRopaRequest\x12\x45\n\tpage_info\x18\x01 \x01(\x0b\x32(.strmprivacy.api.paging.v1alpha.PageInfoR\x08pageInfo\"\x94\x01\n\x0fGetRopaResponse\x12:\n\x04ropa\x18\x01 \x01(\x0b\x32&.strmprivacy.api.entities.v1alpha.RopaR\x04ropa\x12\x45\n\tpage_info\x18\x02 \x01(\x0b\x32(.strmprivacy.api.paging.v1alpha.PageInfoR\x08pageInfo\"\\\n\x13\x43reateRecordRequest\x12\x45\n\x06record\x18\x01 \x01(\x0b\x32-.strmprivacy.api.entities.v1alpha.Ropa.RecordR\x06record\"]\n\x14\x43reateRecordResponse\x12\x45\n\x06record\x18\x01 \x01(\x0b\x32-.strmprivacy.api.entities.v1alpha.Ropa.RecordR\x06record\"/\n\x10GetRecordRequest\x12\x1b\n\x02id\x18\x01 \x01(\tB\x0b\xfa\x42\x08r\x06\xd0\x01\x01\xb0\x01\x01R\x02id\"Z\n\x11GetRecordResponse\x12\x45\n\x06record\x18\x01 \x01(\x0b\x32-.strmprivacy.api.entities.v1alpha.Ropa.RecordR\x06record2\xda\x02\n\x0bRopaService\x12\x66\n\x07GetRopa\x12,.strmprivacy.api.ropa.v1alpha.GetRopaRequest\x1a-.strmprivacy.api.ropa.v1alpha.GetRopaResponse\x12u\n\x0c\x43reateRecord\x12\x31.strmprivacy.api.ropa.v1alpha.CreateRecordRequest\x1a\x32.strmprivacy.api.ropa.v1alpha.CreateRecordResponse\x12l\n\tGetRecord\x12..strmprivacy.api.ropa.v1alpha.GetRecordRequest\x1a/.strmprivacy.api.ropa.v1alpha.GetRecordResponseBg\n\x1fio.strmprivacy.api.ropa.v1alphaP\x01ZBgithub.com/strmprivacy/api-definitions-go/v3/api/ropa/v1alpha;ropab\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.ropa.v1alpha.ropa_v1alpha_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\037io.strmprivacy.api.ropa.v1alphaP\001ZBgithub.com/strmprivacy/api-definitions-go/v3/api/ropa/v1alpha;ropa'
  _GETRECORDREQUEST.fields_by_name['id']._options = None
  _GETRECORDREQUEST.fields_by_name['id']._serialized_options = b'\372B\010r\006\320\001\001\260\001\001'
  _GETROPAREQUEST._serialized_start=263
  _GETROPAREQUEST._serialized_end=350
  _GETROPARESPONSE._serialized_start=353
  _GETROPARESPONSE._serialized_end=501
  _CREATERECORDREQUEST._serialized_start=503
  _CREATERECORDREQUEST._serialized_end=595
  _CREATERECORDRESPONSE._serialized_start=597
  _CREATERECORDRESPONSE._serialized_end=690
  _GETRECORDREQUEST._serialized_start=692
  _GETRECORDREQUEST._serialized_end=739
  _GETRECORDRESPONSE._serialized_start=741
  _GETRECORDRESPONSE._serialized_end=831
  _ROPASERVICE._serialized_start=834
  _ROPASERVICE._serialized_end=1180
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/onboarding/v1/onboarding_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1strmprivacy/api/onboarding/v1/onboarding_v1.proto\x12\x1dstrmprivacy.api.onboarding.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a-strmprivacy/api/entities/v1/entities_v1.proto\x1a\x17validate/validate.proto\"\x8b\x01\n PopulateOnboardingProjectRequest\x12\"\n\x06handle\x18\x01 \x01(\tB\n\xe0\x41\x02\xfa\x42\x04r\x02\x10\x04R\x06handle\x12\x43\n\x07project\x18\x02 \x01(\x0b\x32$.strmprivacy.api.entities.v1.ProjectB\x03\xe0\x41\x02R\x07project\"#\n!PopulateOnboardingProjectResponse2\xb4\x01\n\x11OnboardingService\x12\x9e\x01\n\x19PopulateOnboardingProject\x12?.strmprivacy.api.onboarding.v1.PopulateOnboardingProjectRequest\x1a@.strmprivacy.api.onboarding.v1.PopulateOnboardingProjectResponseBo\n io.strmprivacy.api.onboarding.v1P\x01ZIgithub.com/strmprivacy/api-definitions-go/v3/api/onboarding/v1;onboardingb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.onboarding.v1.onboarding_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n io.strmprivacy.api.onboarding.v1P\001ZIgithub.com/strmprivacy/api-definitions-go/v3/api/onboarding/v1;onboarding'
  _POPULATEONBOARDINGPROJECTREQUEST.fields_by_name['handle']._options = None
  _POPULATEONBOARDINGPROJECTREQUEST.fields_by_name['handle']._serialized_options = b'\340A\002\372B\004r\002\020\004'
  _POPULATEONBOARDINGPROJECTREQUEST.fields_by_name['project']._options = None
  _POPULATEONBOARDINGPROJECTREQUEST.fields_by_name['project']._serialized_options = b'\340A\002'
  _POPULATEONBOARDINGPROJECTREQUEST._serialized_start=190
  _POPULATEONBOARDINGPROJECTREQUEST._serialized_end=329
  _POPULATEONBOARDINGPROJECTRESPONSE._serialized_start=331
  _POPULATEONBOARDINGPROJECTRESPONSE._serialized_end=366
  _ONBOARDINGSERVICE._serialized_start=369
  _ONBOARDINGSERVICE._serialized_end=549
# @@protoc_insertion_point(module_scope)
